! This file is part of SusHi.
! 
! It includes the electroweak correction factor through light quarks.
! 
C-{{{ subroutine G^2l_lf
      
      subroutine G2llf(mhiggs, G2out)
!--------------------------------------------------------
!This routine calculates G^2l_lf for the electroweak
!contributions of light fermions to gluon fusion using
!the complex mass scheme in accordance to
!hep-ph/0404071 and 1007.1891.
!Note that for the electroweak corrections
!we use fixed values of m_W and m_Z, namely:
!m_W = 80.385GeV
!m_Z = 91.1876GeV
!Gamma_W = 2.085GeV
!Gamma_Z = 2.4952GeV
!--------------------------------------------------------
!Additional external factors:
!Prefactor
! alpha_EM / (2 Pi s_W^2) (m_W - i Gamma_W/2)^2/m_H^2!
!MSSM factors
! cos(beta-alpha) for H / sin(beta-alpha) for h
!Be aware of the normalization of the gluon fuson LO
!amplitude, in our case to be multiplied with -3/4.D0!
!--------------------------------------------------------
!October 2012 - S. Liebler
!--------------------------------------------------------
      implicit none
      double precision mhiggs
      double complex G2out

      double precision costhetaW, sinthetaW
      double precision ReA1MW, ImA1MW, ReA1MZ, ImA1MZ
      double precision prefacz, prefacw
      double precision ReG2, ImG2

      call CalcA1MW(mhiggs, ReA1MW, ImA1MW)
      call CalcA1MZ(mhiggs, ReA1MZ, ImA1MZ)

      sinthetaW = sqrt(0.22295D0) !value from PDG 2012
      costhetaW = sqrt(1.D0 - sinthetaW**2)

      prefacz = 2.D0/costhetaW**4 * (5/4.D0 
     &     - 7/3.D0 * sinthetaW**2 + 22/9.D0 * sinthetaW**4)

      prefacw = 4.D0

      ReG2 = prefacz * ReA1MZ + prefacw * ReA1MW
      ImG2 = prefacz * ImA1MZ + prefacw * ImA1MW

      G2out = (1D0,0D0)*ReG2 + (0D0,1D0)*ImG2

      end

C-}}}
C-{{{ subroutine CalcA1MW

      subroutine CalcA1MW(mhiggs, ReA1, ImA1)
!--------------------------------------------------------
!This routine calculates the real and imaginary part
!of A1 taken from hep-ph/0404071 and 1007.1891.
!The grid is obtained in the complex mass scheme
!using m_W = 80.385GeV and Gamma_W = 2.085GeV.
!October 2012 - S. Liebler
!--------------------------------------------------------
      implicit none
      double precision mhiggs, ReA1, ImA1

      integer i1, i2
      double precision realvalues(1481), imvalues(1481)

!     imaginary part
!     stepsize: real values
      data realvalues /-0.03135d0,-0.03461d0,
     -	   -0.03804d0,-0.04164d0,
     -    -0.04541d0,-0.04936d0,
     -    -0.05348d0,-0.05777d0,
     -    -0.06225d0,-0.0669d0,
     -    -0.07174d0,-0.07677d0,
     -    -0.08198d0,-0.08738d0,
     -    -0.09297d0,-0.09875d0,
     -    -0.1047d0,-0.1109d0,
     -    -0.1173d0,-0.1239d0,-0.1307d0,
     -    -0.1377d0,-0.1449d0,-0.1524d0,
     -    -0.1601d0,-0.168d0,
     -    -0.1761d0,-0.1845d0,
     -    -0.1931d0,-0.2019d0,-0.211d0,
     -    -0.2204d0,-0.23d0,-0.2399d0,
     -    -0.25d0,-0.2604d0,
     -    -0.2711d0,-0.2822d0,
     -    -0.2935d0,-0.3051d0,-0.317d0,
     -    -0.3292d0,-0.3418d0,-0.3547d0,
     -    -0.3679d0,-0.3815d0,
     -    -0.3955d0,-0.4098d0,
     -    -0.4246d0,-0.4397d0,-0.4553d0,
     -    -0.4713d0,-0.4877d0,-0.5045d0,
     -    -0.5219d0,-0.5397d0,
     -    -0.5580956128794116d0,
     -    -0.577d0,-0.5964d0,-0.6164d0,
     -    -0.637d0,-0.6583d0,
     -    -0.68022028099785d0,-0.7028d0,
     -    -0.7262d0,-0.7504d0,-0.7753d0,
     -    -0.8011d0,-0.8278d0,
     -    -0.8554d0,-0.884d0,
     -    -0.9135d0,-0.944d0,-0.9755d0,
     -    -1.008d0,-1.042d0,-1.076d0,
     -    -1.112d0,-1.149d0,-1.187d0,
     -    -1.226d0,-1.266d0,-1.307d0,
     -    -1.35d0,-1.393d0,-1.438d0,
     -    -1.484d0,-1.531d0,-1.58d0,
     -    -1.629d0,-1.68d0,-1.732d0,
     -    -1.785d0,-1.84d0,-1.896d0,
     -    -1.953d0,-2.011d0,-2.071d0,
     -    -2.132d0,-2.194d0,-2.258d0,
     -    -2.322d0,-2.389d0,-2.457d0,
     -    -2.526d0,-2.596d0,-2.668d0,
     -    -2.742d0,-2.817d0,-2.894d0,
     -     -2.972d0,-3.052d0,-3.133d0,
     -     -3.217d0,-3.302d0,-3.388d0,
     -     -3.477d0,-3.567d0,-3.66d0,
     -     -3.754d0,-3.85d0,-3.948d0,
     -     -4.049d0,-4.151d0,-4.256d0,
     -     -4.362d0,-4.471d0,-4.582d0,
     -     -4.694d0,-4.808d0,-4.923d0,
     -     -5.038d0,-5.153d0,-5.264d0,
     -     -5.37d0,-5.465d0,-5.541d0,
     -     -5.58d0,-5.55d0,-5.39d0,
     -     -4.992d0,-4.28d0,-3.4d0,
     -     -2.581d0,-1.9d0,-1.344d0,
     -     -0.8842d0,-0.4964d0,
     -     -0.1641d0,0.1249d0,0.3792d0,
     -     0.6055d0,0.8085d0,0.9921d0,
     -     1.159d0,1.312d0,1.453d0,
     -     1.583d0,1.703d0,1.815d0,
     -     1.919d0,2.017d0,2.109d0,2.195d0,
     -     2.276d0,2.353d0,2.425d0,2.494d0,
     -     2.559d0,2.621d0,2.679d0,
     -     2.735d0,2.788d0,2.839d0,2.887d0,
     -     2.933d0,2.978d0,3.02d0,
     -     3.06d0,3.099d0,3.136d0,3.172d0,
     -     3.206d0,3.239d0,3.27d0,
     -     3.3d0,3.329d0,3.357d0,3.384d0,
     -     3.41d0,3.435d0,3.459d0,
     -     3.482d0,3.505d0,3.526d0,3.547d0,
     -     3.567d0,3.586d0,3.604d0,
     -     3.622d0,3.64d0,3.656d0,
     -     3.672d0,3.688d0,3.703d0,3.717d0,
     -     3.731d0,3.745d0,3.758d0,3.77d0,
     -     3.782d0,3.794d0,3.805d0,
     -     3.816d0,3.827d0,3.837d0,
     -     3.847d0,3.856d0,3.866d0,3.874d0,
     -     3.883d0,3.891d0,3.899d0,3.907d0,
     -     3.914d0,3.922d0,3.928d0,
     -     3.935d0,3.942d0,3.948d0,
     -     3.954d0,3.96d0,3.965d0,3.971d0,
     -     3.976d0,3.981d0,3.986d0,3.99d0,
     -     3.995d0,3.999d0,4.003d0,
     -     4.007d0,4.011d0,4.014d0,
     -     4.018d0,4.021d0,4.024d0,4.028d0,
     -     4.031d0,4.033d0,4.036d0,4.039d0,
     -     4.041d0,4.044d0,4.046d0,
     -     4.048d0,4.05d0,4.052d0,
     -     4.054d0,4.056d0,4.057d0,4.059d0,
     -     4.06d0,4.062d0,4.063d0,4.064d0,
     -     4.065d0,4.067d0,4.068d0,
     -     4.068d0,4.069d0,4.07d0,
     -     4.071d0,4.072d0,4.072d0,4.073d0,
     -     4.073d0,4.074d0,4.074d0,4.074d0,
     -     4.075d0,4.075d0,4.075d0,
     -     4.075d0,4.075d0,4.075d0,
     -     4.075d0,4.075d0,4.075d0,4.075d0,
     -     4.074d0,4.074d0,4.074d0,4.074d0,
     -     4.073d0,4.073d0,4.072d0,
     -     4.072d0,4.071d0,4.071d0,
     -     4.07d0,4.07d0,4.069d0,4.068d0,
     -     4.068d0,4.067d0,4.066d0,
     -     4.066d0,4.065d0,4.064d0,4.063d0,
     -     4.062d0,4.061d0,4.061d0,
     -     4.06d0,4.059d0,4.058d0,4.057d0,
     -     4.056d0,4.055d0,4.054d0,4.053d0,
     -     4.052d0,4.05d0,4.049d0,
     -     4.048d0,4.047d0,4.046d0,
     -     4.045d0,4.044d0,4.042d0,4.041d0,
     -     4.04d0,4.039d0,4.037d0,4.036d0,
     -     4.035d0,4.034d0,4.032d0,
     -     4.031d0,4.03d0,4.028d0,4.027d0,
     -     4.026d0,4.024d0,4.023d0,
     -     4.022d0,4.02d0,4.019d0,4.018d0,
     -     4.016d0,4.015d0,4.013d0,
     -     4.012d0,4.011d0,4.009d0,4.008d0,
     -     4.006d0,4.005d0,4.003d0,
     -     4.002d0,4.001d0,3.999d0,3.998d0,
     -     3.996d0,3.995d0,3.993d0,
     -     3.992d0,3.99d0,3.989d0,3.987d0,
     -     3.986d0,3.984d0,3.983d0,
     -     3.981d0,3.98d0,3.978d0,3.977d0,
     -     3.975d0,3.974d0,3.972d0,
     -     3.971d0,3.969d0,3.968d0,3.966d0,
     -     3.965d0,3.963d0,3.962d0,
     -     3.96d0,3.959d0,3.957d0,3.956d0,
     -     3.954d0,3.953d0,3.951d0,
     -     3.95d0,3.948d0,3.947d0,3.945d0,
     -     3.944d0,3.942d0,3.941d0,
     -     3.939d0,3.938d0,3.936d0,3.935d0,
     -    3.933d0,3.932d0,3.93d0,
     -     3.929d0,3.927d0,3.926d0,3.924d0,
     -     3.923d0,3.921d0,3.92d0,
     -     3.918d0,3.917d0,3.915d0,3.914d0,
     -     3.912d0,3.911d0,3.909d0,
     -     3.908d0,3.906d0,3.905d0,3.903d0,
     -     3.902d0,3.901d0,3.899d0,
     -     3.898d0,3.896d0,3.895d0,3.893d0,
     -     3.892d0,3.89d0,3.889d0,
     -     3.887d0,3.886d0,3.885d0,3.883d0,
     -     3.882d0,3.88d0,3.879d0,
     -     3.877d0,3.876d0,3.874d0,3.873d0,
     -     3.872d0,3.87d0,3.869d0,
     -     3.867d0,3.866d0,3.865d0,3.863d0,
     -     3.862d0,3.86d0,3.859d0,
     -     3.858d0,3.856d0,3.855d0,3.853d0,
     -     3.852d0,3.851d0,3.849d0,
     -     3.848d0,3.847d0,3.845d0,3.844d0,
     -     3.843d0,3.841d0,3.84d0,
     -     3.838d0,3.837d0,3.836d0,3.834d0,
     -     3.833d0,3.832d0,3.83d0,
     -     3.829d0,3.828d0,3.826d0,3.825d0,
     -     3.824d0,3.823d0,3.821d0,
     -     3.82d0,3.819d0,3.817d0,3.816d0,
     -     3.815d0,3.813d0,3.812d0,
     -     3.811d0,3.81d0,3.808d0,3.807d0,
     -     3.806d0,3.805d0,3.803d0,
     -     3.802d0,3.801d0,3.799d0,3.798d0,
     -     3.797d0,3.796d0,3.794d0,
     -     3.793d0,3.792d0,3.791d0,3.79d0,
     -     3.788d0,3.787d0,3.786d0,
     -     3.785d0,3.783d0,3.782d0,3.781d0,
     -     3.78d0,3.779d0,3.777d0,
     -     3.776d0,3.775d0,3.774d0,3.773d0,
     -     3.772d0,3.77d0,3.769d0,
     -     3.768d0,3.767d0,3.766d0,3.765d0,
     -     3.763d0,3.762d0,3.761d0,
     -     3.76d0,3.759d0,3.758d0,3.756d0,
     -     3.755d0,3.754d0,3.753d0,
     -     3.752d0,3.751d0,3.75d0,3.749d0,
     -     3.747d0,3.746d0,3.745d0,
     -     3.744d0,3.743d0,3.742d0,3.741d0,
     -     3.74d0,3.739d0,3.738d0,
     -     3.737d0,3.735d0,3.734d0,3.733d0,
     -     3.732d0,3.731d0,3.73d0,
     -     3.729d0,3.728d0,3.727d0,3.726d0,
     -     3.725d0,3.724d0,3.723d0,
     -     3.722d0,3.721d0,3.72d0,3.719d0,
     -     3.717d0,3.716d0,3.715d0,
     -     3.714d0,3.713d0,3.712d0,3.711d0,
     -     3.71d0,3.709d0,3.708d0,
     -     3.707d0,3.706d0,3.705d0,3.704d0,
     -     3.703d0,3.702d0,3.701d0,
     -     3.7d0,3.699d0,3.698d0,3.697d0,
     -     3.696d0,3.696d0,3.695d0,
     -    3.694d0,3.693d0,3.692d0,3.691d0,
     -     3.69d0,3.689d0,3.688d0,
     -     3.687d0,3.686d0,3.685d0,3.684d0,
     -     3.683d0,3.682d0,3.681d0,
     -     3.68d0,3.679d0,3.679d0,3.678d0,
     -     3.677d0,3.676d0,3.675d0,
     -     3.674d0,3.673d0,3.672d0,3.671d0,
     -     3.67d0,3.669d0,3.669d0,
     -     3.668d0,3.667d0,3.666d0,3.665d0,
     -     3.664d0,3.663d0,3.662d0,
     -     3.661d0,3.661d0,3.66d0,3.659d0,
     -     3.658d0,3.657d0,3.656d0,
     -     3.655d0,3.655d0,3.654d0,3.653d0,
     -     3.652d0,3.651d0,3.65d0,
     -     3.649d0,3.649d0,3.648d0,3.647d0,
     -     3.646d0,3.645d0,3.644d0,
     -     3.644d0,3.643d0,3.642d0,3.641d0,
     -     3.64d0,3.64d0,3.639d0,
     -     3.638d0,3.637d0,3.636d0,3.636d0,
     -     3.635d0,3.634d0,3.633d0,
     -     3.632d0,3.632d0,3.631d0,3.63d0,
     -     3.629d0,3.628d0,3.628d0,
     -    3.627d0,3.626d0,3.625d0,3.625d0,
     -     3.624d0,3.623d0,3.622d0,
     -     3.621d0,3.621d0,3.62d0,3.619d0,
     -     3.618d0,3.618d0,3.617d0,
     -     3.616d0,3.615d0,3.615d0,3.614d0,
     -     3.613d0,3.612d0,3.612d0,
     -     3.611d0,3.61d0,3.61d0,3.609d0,
     -     3.608d0,3.607d0,3.607d0,
     -     3.606d0,3.605d0,3.604d0,3.604d0,
     -     3.603d0,3.602d0,3.602d0,
     -     3.601d0,3.6d0,3.6d0,3.599d0,
     -     3.598d0,3.597d0,3.597d0,
     -     3.596d0,3.595d0,3.595d0,3.594d0,
     -     3.593d0,3.593d0,3.592d0,
     -     3.591d0,3.591d0,3.59d0,3.589d0,
     -     3.589d0,3.588d0,3.587d0,
     -     3.586d0,3.586d0,3.585d0,3.584d0,
     -     3.584d0,3.583d0,3.583d0,
     -     3.582d0,3.581d0,3.581d0,3.58d0,
     -     3.579d0,3.579d0,3.578d0,
     -     3.577d0,3.577d0,3.576d0,3.575d0,
     -    3.575d0,3.574d0,3.573d0,
     -     3.573d0,3.572d0,3.572d0,3.571d0,
     -     3.57d0,3.57d0,3.569d0,
     -     3.568d0,3.568d0,3.567d0,3.567d0,
     -     3.566d0,3.565d0,3.565d0,
     -     3.564d0,3.564d0,3.563d0,3.562d0,
     -     3.562d0,3.561d0,3.561d0,
     -     3.56d0,3.559d0,3.559d0,3.558d0,
     -     3.558d0,3.557d0,3.556d0,
     -     3.556d0,3.555d0,3.555d0,3.554d0,
     -     3.553d0,3.553d0,3.552d0,
     -     3.552d0,3.551d0,3.551d0,3.55d0,
     -     3.549d0,3.549d0,3.548d0,
     -     3.548d0,3.547d0,3.547d0,3.546d0,
     -     3.545d0,3.545d0,3.544d0,
     -     3.544d0,3.543d0,3.543d0,3.542d0,
     -     3.542d0,3.541d0,3.54d0,
     -     3.54d0,3.539d0,3.539d0,3.538d0,
     -     3.538d0,3.537d0,3.537d0,
     -     3.536d0,3.536d0,3.535d0,3.535d0,
     -     3.534d0,3.533d0,3.533d0,
     -     3.532d0,3.532d0,3.531d0,3.531d0,
     -     3.53d0,3.53d0,3.529d0,
     -     3.529d0,3.528d0,3.528d0,3.527d0,
     -     3.527d0,3.526d0,3.526d0,
     -     3.525d0,3.525d0,3.524d0,3.524d0,
     -     3.523d0,3.523d0,3.522d0,
     -     3.522d0,3.521d0,3.521d0,3.52d0,
     -     3.52d0,3.519d0,3.519d0,
     -     3.518d0,3.518d0,3.517d0,3.517d0,
     -     3.516d0,3.516d0,3.515d0,
     -     3.515d0,3.514d0,3.514d0,3.513d0,
     -     3.513d0,3.512d0,3.512d0,
     -     3.511d0,3.511d0,3.51d0,3.51d0,
     -     3.509d0,3.509d0,3.509d0,
     -     3.508d0,3.508d0,3.507d0,3.507d0,
     -     3.506d0,3.506d0,3.505d0,
     -     3.505d0,3.504d0,3.504d0,3.503d0,
     -     3.503d0,3.503d0,3.502d0,
     -     3.502d0,3.501d0,3.501d0,3.5d0,
     -     3.5d0,3.499d0,3.499d0,
     -     3.498d0,3.498d0,3.498d0,3.497d0,
     -     3.497d0,3.496d0,3.496d0,
     -     3.495d0,3.495d0,3.495d0,3.494d0,
     -     3.494d0,3.493d0,3.493d0,
     -     3.492d0,3.492d0,3.491d0,3.491d0,
     -     3.491d0,3.49d0,3.49d0,
     -     3.489d0,3.489d0,3.489d0,3.488d0,
     -     3.488d0,3.487d0,3.487d0,
     -     3.486d0,3.486d0,3.486d0,
     -     3.485166062704483d0,3.485d0,
     -     3.484d0,3.484d0,3.484d0,3.483d0,
     -     3.483d0,3.482d0,3.482d0,
     -     3.481d0,3.481d0,3.481d0,3.48d0,
     -     3.48d0,3.479d0,3.479d0,
     -     3.479d0,3.478d0,3.478d0,3.477d0,
     -     3.477d0,3.477d0,3.476d0,
     -     3.476d0,3.476d0,3.475d0,3.475d0,
     -     3.474d0,3.474d0,3.474d0,
     -     3.473d0,3.473d0,3.472d0,3.472d0,
     -     3.472d0,3.471d0,3.471d0,
     -     3.47d0,3.47d0,3.47d0,3.469d0,
     -     3.469d0,3.469d0,3.468d0,
     -     3.468d0,3.467d0,3.467d0,3.467d0,
     -     3.466d0,3.466d0,3.466d0,
     -     3.465d0,3.465d0,3.465d0,3.464d0,
     -     3.464d0,3.463d0,3.463d0,
     -     3.463d0,3.462d0,3.462d0,3.462d0,
     -     3.461d0,3.461d0,3.461d0,
     -     3.46d0,3.46d0,3.459d0,3.459d0,
     -     3.459d0,3.458d0,3.458d0,
     -     3.458d0,3.457d0,3.457d0,3.457d0,
     -     3.456d0,3.456d0,3.456d0,
     -     3.455d0,3.455d0,3.455d0,3.454d0,
     -     3.454d0,3.454d0,3.453d0,
     -     3.453d0,3.453d0,3.452d0,3.452d0,
     -     3.452d0,3.451d0,3.451d0,
     -     3.451d0,3.45d0,3.45d0,3.449d0,
     -     3.449d0,3.449d0,3.449d0,
     -     3.448d0,3.448d0,3.448d0,3.447d0,
     -     3.447d0,3.447d0,3.446d0,
     -     3.446d0,3.446d0,3.445d0,3.445d0,
     -     3.445d0,3.444d0,3.444d0,
     -     3.444d0,3.443d0,3.443d0,3.443d0,
     -     3.442d0,3.442d0,3.442d0,
     -     3.441d0,3.441d0,3.441d0,3.44d0,
     -     3.44d0,3.44d0,3.44d0,
     -     3.439d0,3.439d0,3.439d0,3.438d0,
     -     3.438d0,3.438d0,3.437d0,
     -     3.437d0,3.437d0,3.436417635466521d0,
     -     3.436d0,3.436d0,
     -     3.436d0,3.435d0,3.435d0,3.435d0,
     -     3.434d0,3.434d0,3.434d0,
     -     3.433d0,3.433d0,3.433d0,3.433d0,
     -     3.432d0,3.432d0,3.432d0,
     -     3.431d0,3.431d0,3.431d0,3.43d0,
     -     3.43d0,3.43d0,3.43d0,
     -     3.429d0,3.429d0,3.429d0,3.428d0,
     -     3.428d0,3.428d0,3.428d0,
     -     3.427d0,3.427d0,3.427d0,3.426d0,
     -     3.426d0,3.426d0,3.426d0,
     -     3.425d0,3.425d0,3.425d0,
     -     3.4244205029996766d0,3.424d0,
     -     3.424d0,3.424d0,3.423d0,3.423d0,
     -     3.423d0,3.422d0,3.422d0,
     -     3.422d0,3.422d0,3.421d0,3.421d0,
     -     3.4208235311635518d0,
     -     3.421d0,3.42d0,3.42d0,3.42d0,
     -     3.419d0,3.419d0,3.419d0,
     -     3.419d0,3.418d0,3.418d0,3.418d0,
     -     3.418d0,3.417d0,3.417d0,
     -     3.417d0,3.417d0,3.416d0,3.416d0,
     -     3.416d0,3.415d0,3.415d0,
     -     3.415d0,3.415d0,3.414d0,3.414d0,
     -     3.414d0,3.414d0,3.413d0,
     -     3.413d0,3.413d0,3.413d0,3.412d0,
     -     3.412d0,3.412d0,3.412d0,
     -     3.411d0,3.411d0,3.411d0,3.411d0,
     -     3.41d0,3.41d0,3.41d0,
     -     3.41d0,3.409d0,3.409d0,3.409d0,
     -     3.409d0,3.408d0,3.408d0,
     -     3.408d0,3.408d0,3.407d0,3.407d0,
     -     3.407d0,3.407d0,3.406d0,
     -     3.406d0,3.406d0,3.406d0,3.405d0,
     -     3.405d0,3.405d0,3.405d0,
     -     3.404d0,3.404d0,3.404d0,3.404d0,
     -     3.403d0,3.403d0,3.403d0,
     -     3.403d0,3.403d0,3.402d0,3.402d0,
     -     3.402d0,3.402d0,3.401d0,
     -     3.401d0,3.401d0,3.401d0,3.4d0,
     -     3.4d0,3.4d0,3.4d0,3.399d0,
     -     3.399d0,3.399d0,3.399d0,3.399d0,
     -     3.398d0,3.398d0,3.398d0,
     -     3.398d0,3.397d0,3.397d0,3.397d0,
     -     3.397d0,3.397d0,3.396d0,
     -     3.396d0,3.396d0,3.396d0,3.395d0,
     -     3.395d0,3.395d0,3.395d0,
     -     3.394d0,3.394d0,3.394d0,3.394d0,
     -     3.394d0,3.393d0,3.393d0,
     -     3.393d0,3.393d0,3.393d0,3.392d0,
     -     3.392d0,3.392d0,3.392d0,
     -     3.391d0,3.391d0,3.391d0,3.391d0,
     -     3.391d0,3.39d0,3.39d0,
     -     3.39d0,3.39d0,3.39d0,3.389d0,
     -     3.389d0,3.389d0,3.389d0,
     -     3.388d0,3.388d0,3.388d0,3.388d0,
     -     3.388d0,3.387d0,3.387d0,
     -     3.387d0,3.387d0,3.387d0,3.386d0,
     -     3.386d0,3.386d0,3.386d0,
     -     3.386d0,3.385d0,3.385d0,3.385d0,
     -     3.385d0,3.385d0,3.384d0,
     -     3.384d0,3.384d0,3.384d0,3.384d0,
     -     3.383d0,3.383d0,3.383d0,
     -     3.383d0,3.383d0,3.382d0,3.382d0,
     -     3.382d0,3.382d0,3.382d0,
     -     3.381d0,3.381d0,3.381d0,3.381d0,
     -     3.381d0,3.38d0,3.38d0,
     -     3.38d0,3.38d0,3.38d0,3.379d0,
     -     3.379d0,3.379d0,3.379d0,
     -     3.379d0,3.378d0,3.378d0,3.378d0,
     -     3.378d0,3.378d0,3.377d0,
     -     3.377d0,3.377d0,3.377d0,3.377d0,
     -     3.377d0,3.376d0,3.376d0,
     -     3.376d0,3.376d0,3.376d0,3.375d0,
     -     3.375d0,3.375d0,3.375d0,
     -     3.375d0,3.374d0,3.374d0,3.374d0,
     -     3.374d0,3.374d0,3.374d0,
     -     3.373d0,3.373d0,3.373d0,3.373d0,
     -     3.373d0,3.372d0,3.372d0,
     -     3.372d0,3.372d0,3.372d0,3.372d0,
     -     3.371d0,3.371d0,3.371d0,
     -     3.371d0,3.371d0,3.37d0,3.37d0,
     -     3.37d0,3.37d0,3.37d0,3.37d0,
     -     3.369d0,3.369d0,3.369d0,3.369d0,
     -     3.369d0,3.369d0,3.368d0,
     -     3.368d0,3.368d0,3.368d0,3.368d0,
     -     3.368d0,3.367d0,3.367d0,
     -     3.367d0,3.367d0,3.367d0,3.366d0,
     -     3.366d0,3.366d0,3.366d0,
     -     3.366d0,3.366d0,3.365d0,3.365d0,
     -     3.365d0,3.365d0,3.365d0,
     -     3.365d0,3.364d0,3.364d0,3.364d0,
     -     3.364d0,3.364d0,3.364d0,
     -     3.363d0,3.363d0,3.363d0,3.363d0,
     -     3.363d0,3.363d0,3.362d0,
     -     3.362d0,3.362d0,3.362d0,3.362d0,
     -     3.362d0,3.361d0,3.361d0,
     -     3.361d0,3.361d0,3.361d0,3.361d0,
     -     3.361d0,3.36d0,3.36d0,
     -     3.36d0,3.36d0,3.36d0,3.36d0,
     -     3.359d0,3.359d0,3.359d0,
     -     3.359d0,3.359d0,3.359d0,3.358d0,
     -     3.358d0,3.358d0,3.358d0,
     -     3.358d0,3.358d0,3.358d0,3.357d0,
     -     3.357d0,3.357d0,3.357d0,
     -     3.357d0,3.357d0,3.356d0,3.356d0,
     -     3.356d0,3.356d0,3.356d0,
     -     3.356d0,3.356d0,3.355d0,3.355d0,
     -     3.355d0,3.355d0,3.355d0,
     -     3.355d0,3.354d0,3.354d0,3.354d0,
     -     3.354d0,3.354d0,3.354d0,
     -     3.354d0,3.353d0,3.353d0,3.353d0,
     -     3.353d0,3.353d0,3.353d0,
     -     3.353d0,3.352d0,3.352d0,3.352d0,
     -     3.352d0,3.352d0,3.352d0,
     -     3.351d0,3.351d0,3.351d0,3.351d0,
     -     3.351d0,3.351d0,3.351d0,
     -     3.35d0,3.35d0,3.35d0,3.35d0,
     -     3.35d0,3.35d0,3.35d0,3.349d0,
     -     3.349d0,3.349d0,3.349d0,
     -     3.349d0,3.349d0,3.349d0/

      data imvalues /-0.0008242d0,-0.0009112d0,-0.001003d0,
     -     -0.0011d0,-0.001201d0,
     -     -0.001308d0,-0.001419d0,
     -     -0.001536d0,-0.001658d0,
     -     -0.001786d0,-0.001919d0,
     -     -0.002057d0,-0.002202d0,
     -     -0.002352d0,-0.002509d0,
     -     -0.002671d0,-0.00284d0,
     -     -0.003016d0,-0.003198d0,
     -     -0.003387d0,-0.003584d0,
     -     -0.003787d0,-0.003998d0,
     -     -0.004217d0,-0.004443d0,
     -     -0.004678d0,-0.004921d0,
     -     -0.005173d0,-0.005434d0,
     -     -0.005705d0,-0.005985d0,
     -     -0.006274d0,-0.006575d0,
     -     -0.006886d0,-0.007208d0,
     -     -0.007541d0,-0.007887d0,
     -     -0.008245d0,-0.008616d0,
     -     -0.009001d0,-0.009399d0,
     -     -0.009813d0,-0.01024d0,
     -     -0.01069d0,-0.01115d0,
     -     -0.01163d0,-0.01212d0,
     -     -0.01264d0,-0.01318d0,
     -     -0.01374d0,-0.01432d0,
     -     -0.01492d0,-0.01555d0,
     -     -0.01621d0,-0.0169d0,
     -     -0.01761d0,-0.01836d0,
     -     -0.01914d0,-0.01997d0,
     -     -0.02083d0,-0.02174d0,
     -     -0.0227d0,-0.02372d0,
     -     -0.02481d0,-0.02599d0,
     -     -0.02729d0,-0.02874d0,
     -     -0.03036d0,-0.03218d0,
     -     -0.03425d0,-0.03661d0,
     -     -0.03929d0,-0.04234d0,
     -     -0.04581d0,-0.04973d0,
     -     -0.05416d0,-0.05914d0,
     -     -0.06472d0,-0.07094d0,
     -     -0.07787d0,-0.08554d0,
     -     -0.09401d0,-0.1033d0,-0.1135d0,
     -     -0.1247d0,-0.1369d0,-0.1501d0,
     -     -0.1645d0,-0.18d0,
     -     -0.1968d0,-0.2149d0,
     -     -0.2343d0,-0.2552d0,-0.2775d0,
     -     -0.3014d0,-0.3269d0,-0.3542d0,
     -     -0.3832d0,-0.4141d0,
     -     -0.447d0,-0.4819d0,-0.519d0,
     -     -0.5583d0,-0.6d0,-0.6442d0,
     -     -0.6909d0,-0.7405d0,-0.7929d0,
     -     -0.8484d0,-0.9072d0,
     -     -0.9693d0,-1.035d0,-1.105d0,
     -     -1.178d0,-1.256d0,-1.339d0,
     -     -1.427d0,-1.52d0,-1.619d0,
     -     -1.724d0,-1.836d0,-1.955d0,
     -     -2.082d0,-2.218d0,-2.363d0,
     -     -2.52d0,-2.688d0,-2.87d0,
     -     -3.067d0,-3.281d0,-3.515d0,
     -     -3.772d0,-4.057d0,-4.373d0,
     -     -4.729d0,-5.133d0,-5.597d0,
     -     -6.136d0,-6.769d0,-7.506d0,
     -     -8.307d0,-8.996d0,-9.366d0,
     -     -9.446d0,-9.371d0,-9.229d0,
     -     -9.06d0,-8.883d0,-8.706d0,
     -     -8.534d0,-8.368d0,-8.208d0,
     -     -8.055d0,-7.908d0,-7.767d0,
     -     -7.632d0,-7.503d0,-7.379d0,
     -     -7.259d0,-7.144d0,-7.033d0,
     -     -6.926d0,-6.822d0,-6.722d0,
     -     -6.625d0,-6.532d0,-6.441d0,
     -     -6.352d0,-6.267d0,-6.183d0,
     -     -6.102d0,-6.023d0,-5.946d0,
     -     -5.871d0,-5.798d0,-5.727d0,
     -     -5.658d0,-5.59d0,-5.524d0,
     -     -5.459d0,-5.395d0,-5.333d0,
     -     -5.273d0,-5.213d0,-5.155d0,
     -     -5.098d0,-5.042d0,-4.988d0,
     -     -4.934d0,-4.882d0,-4.83d0,
     -     -4.779d0,-4.73d0,-4.681d0,
     -     -4.633d0,-4.586d0,-4.54d0,
     -     -4.494d0,-4.45d0,-4.406d0,
     -     -4.363d0,-4.321d0,-4.279d0,
     -     -4.238d0,-4.198d0,-4.158d0,
     -     -4.119d0,-4.08d0,-4.043d0,
     -     -4.005d0,-3.969d0,-3.933d0,
     -     -3.897d0,-3.862d0,-3.827d0,
     -     -3.793d0,-3.76d0,-3.727d0,
     -     -3.694d0,-3.662d0,-3.631d0,
     -     -3.599d0,-3.569d0,-3.538d0,
     -     -3.508d0,-3.479d0,-3.45d0,
     -     -3.421d0,-3.393d0,-3.365d0,
     -     -3.337d0,-3.31d0,-3.283d0,
     -     -3.257d0,-3.23d0,-3.205d0,
     -     -3.179d0,-3.154d0,
     -     -3.129089504497711d0,-3.105d0,
     -     -3.08d0,-3.056d0,-3.033d0,
     -     -3.009d0,-2.986d0,-2.963d0,
     -     -2.941d0,-2.919d0,-2.897d0,
     -     -2.875d0,-2.853d0,-2.832d0,
     -     -2.811d0,-2.791d0,-2.77d0,
     -     -2.75d0,-2.73d0,-2.71d0,
     -     -2.69d0,-2.671d0,-2.652d0,
     -     -2.633d0,-2.614d0,-2.596d0,
     -     -2.577d0,-2.559d0,-2.541d0,
     -     -2.524d0,-2.506d0,-2.489d0,
     -     -2.472d0,-2.455d0,-2.438d0,
     -     -2.421d0,-2.405d0,-2.389d0,
     -     -2.373d0,-2.357d0,-2.341d0,
     -     -2.325d0,-2.31d0,-2.295d0,
     -     -2.28d0,-2.265d0,-2.25d0,
     -     -2.235d0,-2.221d0,-2.206d0,
     -     -2.192d0,-2.178d0,-2.164d0,
     -     -2.15d0,-2.137d0,-2.123d0,
     -     -2.11d0,-2.096d0,-2.083d0,
     -     -2.07d0,-2.057d0,-2.044d0,
     -     -2.032d0,-2.019d0,-2.007d0,
     -     -1.995d0,-1.982d0,-1.97d0,
     -     -1.958d0,-1.947d0,-1.935d0,
     -     -1.923d0,-1.912d0,-1.9d0,
     -     -1.889d0,-1.878d0,-1.867d0,
     -     -1.856d0,-1.845d0,-1.834d0,
     -     -1.823d0,-1.813d0,-1.802d0,
     -     -1.792d0,-1.781d0,-1.771d0,
     -     -1.761d0,-1.751d0,-1.741d0,
     -     -1.731d0,-1.721d0,-1.712d0,
     -     -1.702d0,-1.692d0,-1.683d0,
     -     -1.673d0,-1.664d0,-1.655d0,
     -     -1.646d0,-1.637d0,-1.628d0,
     -     -1.619d0,-1.61d0,-1.601d0,
     -     -1.592d0,-1.584d0,-1.575d0,
     -     -1.567d0,-1.558d0,-1.55d0,
     -     -1.542d0,-1.533d0,-1.525d0,
     -     -1.517d0,-1.509d0,-1.501d0,
     -     -1.493d0,-1.486d0,-1.478d0,
     -     -1.47d0,-1.462d0,-1.455d0,
     -     -1.447d0,-1.44d0,-1.432d0,
     -     -1.425d0,-1.418d0,-1.411d0,
     -     -1.403d0,-1.396d0,-1.389d0,
     -     -1.382d0,-1.375d0,-1.368d0,
     -     -1.362d0,-1.355d0,-1.348d0,
     -     -1.341d0,-1.335d0,-1.328d0,
     -     -1.321d0,-1.315d0,-1.309d0,
     -     -1.302d0,-1.296d0,-1.289d0,
     -     -1.283d0,-1.277d0,-1.271d0,
     -     -1.265d0,-1.259d0,-1.253d0,
     -     -1.247d0,-1.241d0,-1.235d0,
     -     -1.229d0,-1.223d0,-1.217d0,
     -     -1.212d0,-1.206d0,-1.2d0,
     -     -1.194541539215489d0,
     -     -1.189d0,-1.183d0,-1.178d0,
     -     -1.172d0,-1.167d0,-1.162d0,
     -     -1.156d0,-1.151d0,-1.146d0,
     -     -1.141d0,-1.135d0,-1.13d0,
     -     -1.125d0,-1.12d0,-1.115d0,
     -     -1.11d0,-1.105d0,-1.1d0,
     -     -1.095d0,-1.09d0,-1.085d0,
     -     -1.08d0,-1.076d0,-1.071d0,
     -     -1.066d0,-1.061d0,-1.057d0,
     -     -1.052d0,-1.048d0,-1.043d0,
     -     -1.038d0,-1.034d0,-1.029d0,
     -     -1.025d0,-1.021d0,-1.016d0,
     -     -1.012d0,-1.007d0,-1.003d0,
     -     -0.9989d0,-0.9946d0,
     -     -0.9904d0,-0.9862d0,-0.982d0,
     -     -0.9779d0,-0.9738d0,
     -     -0.9697d0,-0.9656d0,-0.9616d0,
     -     -0.9575d0,-0.9535d0,
     -     -0.9495825800999202d0,-0.9456d0,
     -     -0.9417d0,
     -     -0.9378d0,-0.934d0,-0.9301d0,
     -     -0.9263d0,-0.9225d0,
     -     -0.9187d0,-0.915d0,-0.9113d0,
     -     -0.9076d0,-0.9039d0,
     -     -0.9002d0,-0.8966d0,-0.893d0,
     -     -0.8894d0,-0.8858d0,
     -     -0.8823d0,-0.8787d0,-0.8752d0,
     -     -0.8718d0,-0.8683d0,
     -     -0.8648d0,-0.8614d0,-0.858d0,
     -     -0.8546d0,-0.8513d0,
     -     -0.8479d0,-0.8446d0,-0.8413d0,
     -     -0.838d0,-0.8348d0,
     -     -0.8315d0,-0.8283d0,-0.8251d0,
     -     -0.8219d0,-0.8187d0,
     -     -0.8156d0,-0.8125d0,-0.8093d0,
     -     -0.8063d0,-0.8032d0,
     -     -0.8001d0,-0.7971d0,-0.794d0,
     -     -0.791d0,-0.7881d0,
     -     -0.7851d0,-0.7821d0,-0.7792d0,
     -     -0.7763d0,-0.7734d0,
     -     -0.7705d0,-0.7676d0,-0.7647d0,
     -     -0.7619d0,-0.7591d0,
     -     -0.7563d0,-0.7535d0,-0.7507d0,
     -     -0.7479d0,-0.7452d0,
     -     -0.7424d0,-0.7397d0,-0.737d0,
     -     -0.7343d0,-0.7317d0,
     -     -0.729d0,-0.7264d0,-0.7237d0,
     -     -0.7211d0,-0.7185d0,
     -     -0.7159d0,-0.7133d0,-0.7108d0,
     -     -0.7082d0,-0.7057d0,
     -     -0.7032d0,-0.7007d0,-0.6982d0,
     -     -0.6957d0,-0.6933d0,
     -     -0.6908d0,-0.6884d0,-0.6859d0,
     -     -0.6835d0,-0.6811d0,
     -     -0.6787d0,-0.6764d0,-0.674d0,
     -     -0.6717d0,-0.6693d0,
     -     -0.667d0,-0.6647d0,-0.6624d0,
     -     -0.6601d0,-0.6578d0,
     -     -0.6556d0,-0.6533d0,-0.6511d0,
     -     -0.6488406566926053d0,-0.6466d0,
     -     -0.6444d0,
     -     -0.6422d0,-0.64d0,-0.6379d0,
     -     -0.6357d0,-0.6336d0,
     -     -0.6314d0,-0.6293d0,-0.6272d0,
     -     -0.6251d0,-0.623d0,
     -     -0.6209d0,-0.6188d0,-0.6167d0,
     -     -0.6147d0,-0.6126d0,
     -     -0.6106d0,-0.6086d0,-0.6066d0,
     -     -0.6046d0,-0.6026d0,
     -     -0.6006d0,-0.5986d0,-0.5966d0,
     -     -0.5947d0,-0.5927d0,
     -     -0.5908d0,-0.5889d0,-0.587d0,
     -     -0.5851d0,-0.5832d0,
     -     -0.5813d0,-0.5794d0,-0.5775d0,
     -     -0.5757d0,-0.5738d0,
     -     -0.572d0,-0.5701d0,-0.5683d0,
     -     -0.5665d0,-0.5647d0,
     -     -0.5629d0,-0.5611d0,-0.5593d0,
     -     -0.5575d0,-0.5558d0,
     -     -0.554d0,-0.5523d0,-0.5505d0,
     -     -0.5488d0,-0.5471d0,
     -     -0.5454d0,-0.5437d0,-0.542d0,
     -     -0.5403d0,-0.5386d0,
     -     -0.5369d0,-0.5352d0,-0.5336d0,
     -     -0.5319d0,-0.5303d0,
     -     -0.5286d0,-0.527d0,-0.5254d0,
     -     -0.5238d0,-0.5222d0,
     -     -0.5206d0,-0.519d0,-0.5174d0,
     -     -0.5158d0,-0.5143d0,
     -     -0.5127d0,-0.5111d0,-0.5096d0,
     -     -0.508d0,-0.5065d0,
     -     -0.505d0,-0.5035d0,-0.502d0,
     -     -0.5004d0,-0.4989d0,
     -     -0.4975d0,-0.496d0,-0.4945d0,
     -     -0.493d0,-0.4915d0,
     -     -0.4901d0,-0.4886d0,-0.4872d0,
     -     -0.4857d0,-0.4843d0,
     -     -0.4829d0,-0.4815d0,-0.4801d0,
     -     -0.4786d0,-0.4772d0,
     -     -0.4758d0,-0.4745d0,-0.4731d0,
     -     -0.4717d0,-0.4703d0,
     -     -0.469d0,-0.4676d0,-0.4662d0,
     -     -0.4649d0,-0.4635d0,
     -     -0.4622d0,-0.4609d0,-0.4596d0,
     -     -0.4582d0,-0.4569d0,
     -     -0.4556d0,-0.4543d0,-0.453d0,
     -     -0.4517d0,-0.4504d0,
     -     -0.4492d0,-0.4479d0,-0.4466d0,
     -     -0.4454d0,-0.4441d0,
     -     -0.4428d0,-0.4416d0,-0.4404d0,
     -     -0.4391d0,-0.4379d0,
     -     -0.4367d0,-0.4354d0,-0.4342d0,
     -     -0.433d0,-0.4318d0,
     -     -0.4306d0,-0.4294d0,-0.4282d0,
     -     -0.427d0,-0.4258d0,
     -     -0.4247d0,-0.4235d0,-0.4223d0,
     -     -0.4212d0,-0.42d0,
     -     -0.4189d0,-0.4177d0,-0.4166d0,
     -     -0.4154d0,-0.4143d0,
     -     -0.4132d0,-0.412d0,-0.4109d0,
     -     -0.4098d0,-0.4087d0,
     -     -0.4076d0,-0.4065d0,-0.4054d0,
     -     -0.4043d0,-0.4032d0,
     -     -0.4021d0,-0.4011d0,-0.4d0,
     -     -0.3989d0,-0.3978d0,
     -     -0.3968d0,-0.3957d0,-0.3947d0,
     -     -0.3936d0,-0.3926d0,
     -     -0.3915d0,-0.3905d0,-0.3895d0,
     -     -0.3884d0,-0.3874d0,
     -     -0.3864d0,-0.3854d0,-0.3844d0,
     -     -0.3834d0,-0.3824d0,
     -     -0.3814d0,-0.3804d0,-0.3794d0,
     -     -0.3784d0,-0.3774d0,
     -     -0.3764d0,-0.3754d0,-0.3745d0,
     -     -0.3735d0,-0.3725d0,
     -     -0.3716d0,-0.3706d0,-0.3697d0,
     -     -0.3687d0,-0.3678d0,
     -     -0.3668d0,-0.3659d0,-0.3649d0,
     -     -0.364d0,-0.3631d0,
     -     -0.3622d0,-0.3612d0,-0.3603d0,
     -     -0.3594d0,-0.3585d0,
     -     -0.3576d0,-0.3567d0,-0.3558d0,
     -     -0.3549d0,-0.354d0,
     -     -0.3531d0,-0.3522d0,-0.3513d0,
     -     -0.3504d0,-0.3496d0,
     -     -0.3487d0,-0.3478d0,-0.347d0,
     -     -0.3461d0,-0.3452d0,
     -     -0.3444d0,-0.3435d0,-0.3427d0,
     -     -0.3418d0,-0.341d0,
     -     -0.3401d0,-0.3393d0,-0.3385d0,
     -     -0.3376d0,-0.3368d0,
     -     -0.336d0,-0.3351d0,-0.3343d0,
     -     -0.3335d0,-0.3327d0,
     -     -0.3319d0,-0.3311d0,-0.3303d0,
     -     -0.3295d0,-0.3287d0,
     -     -0.3279d0,-0.3271d0,-0.3263d0,
     -     -0.3255d0,-0.3247d0,
     -     -0.3239d0,-0.3231d0,-0.3224d0,
     -     -0.3216d0,-0.3208d0,
     -     -0.3201d0,-0.3193d0,-0.3185d0,
     -     -0.3178d0,-0.317d0,
     -     -0.3163d0,-0.3155d0,-0.3148d0,
     -     -0.314d0,-0.3133d0,
     -     -0.3125d0,-0.3118d0,-0.3111d0,
     -     -0.3103d0,-0.3096d0,
     -     -0.3089d0,-0.3081d0,-0.3074d0,
     -     -0.3067d0,-0.306d0,
     -     -0.3053d0,-0.3045d0,-0.3038d0,
     -     -0.3031d0,-0.3024d0,
     -     -0.3017d0,-0.301d0,-0.3003d0,
     -     -0.2996d0,-0.2989d0,
     -     -0.2982d0,-0.2976d0,-0.2969d0,
     -     -0.2962d0,-0.2955d0,
     -     -0.2948d0,-0.2941d0,-0.2935d0,
     -     -0.2928d0,-0.2921d0,
     -     -0.2915d0,-0.2908d0,-0.2901d0,
     -     -0.2895d0,-0.2888d0,
     -     -0.2882d0,-0.2875d0,-0.2869d0,
     -     -0.2862d0,-0.2856d0,
     -     -0.2849d0,-0.2843d0,-0.2836d0,
     -     -0.283d0,-0.2824d0,
     -     -0.2817d0,-0.2811d0,-0.2805d0,
     -     -0.2798d0,-0.2792d0,
     -     -0.2786d0,-0.278d0,-0.2773d0,
     -     -0.2767d0,-0.2761d0,
     -     -0.2755d0,-0.2749d0,-0.2743d0,
     -     -0.2737d0,-0.2731d0,
     -     -0.2725d0,-0.2719d0,-0.2713d0,
     -     -0.2707d0,-0.2701d0,
     -     -0.2695d0,-0.2689d0,-0.2683d0,
     -     -0.2677d0,-0.2671d0,
     -     -0.2666d0,-0.266d0,-0.2654d0,
     -     -0.2648d0,-0.2642d0,
     -     -0.2637d0,-0.2631d0,-0.2625d0,
     -     -0.262d0,-0.2614d0,
     -     -0.2608d0,-0.2603d0,-0.2597d0,
     -     -0.2591d0,-0.2586d0,
     -     -0.258d0,-0.2575d0,-0.2569d0,
     -     -0.2564d0,-0.2558d0,
     -     -0.2553d0,-0.2547d0,-0.2542d0,
     -     -0.2536d0,-0.2531d0,
     -     -0.2526d0,-0.252d0,-0.2515d0,
     -     -0.251d0,-0.2504d0,
     -     -0.2499d0,-0.2494d0,-0.2489d0,
     -     -0.2483d0,-0.2478d0,
     -     -0.2473d0,-0.2468d0,-0.2462d0,
     -     -0.2457d0,-0.2452d0,
     -     -0.2447d0,-0.2442d0,-0.2437d0,
     -     -0.2432d0,-0.2427d0,
     -     -0.2422d0,-0.2417d0,-0.2412d0,
     -     -0.2407d0,-0.2402d0,
     -     -0.2397d0,-0.2392d0,-0.2387d0,
     -     -0.2382d0,-0.2377d0,
     -     -0.2372d0,-0.2367d0,-0.2362d0,
     -     -0.2357d0,-0.2353d0,
     -     -0.2348d0,-0.2343d0,-0.2338d0,
     -     -0.2333d0,-0.2329d0,
     -     -0.2324d0,-0.2319d0,-0.2314d0,
     -     -0.231d0,-0.2305d0,
     -     -0.23d0,-0.2296d0,-0.2291d0,
     -     -0.2287d0,-0.2282d0,
     -     -0.2277d0,-0.2273d0,-0.2268d0,
     -     -0.2264d0,-0.2259d0,
     -     -0.2254d0,-0.225d0,-0.2245d0,
     -     -0.2241d0,-0.2236d0,
     -     -0.2232d0,-0.2228d0,-0.2223d0,
     -     -0.2219d0,-0.2214d0,
     -     -0.221d0,-0.2206d0,-0.2201d0,
     -     -0.2197d0,-0.2192d0,
     -     -0.2188d0,-0.2184d0,-0.2179d0,
     -     -0.2175d0,-0.2171d0,
     -     -0.2167d0,-0.2162d0,-0.2158d0,
     -     -0.2154d0,-0.215d0,
     -     -0.2145d0,-0.2141d0,-0.2137d0,
     -     -0.2133d0,-0.2129d0,
     -     -0.2125d0,-0.2121d0,-0.2116d0,
     -     -0.2112d0,-0.2108d0,
     -     -0.2104d0,-0.21d0,-0.2096d0,
     -     -0.2092d0,-0.2088d0,
     -     -0.2084d0,-0.208d0,-0.2076d0,
     -     -0.2072d0,-0.2068d0,
     -     -0.2064d0,-0.206d0,-0.2056d0,
     -     -0.2052d0,-0.2048d0,
     -     -0.2044d0,-0.204d0,-0.2036d0,
     -     -0.2033d0,-0.2029d0,
     -     -0.2025d0,-0.2021d0,-0.2017d0,
     -     -0.2013d0,-0.201d0,
     -     -0.2006d0,-0.2002d0,-0.1998d0,
     -     -0.1994d0,-0.1991d0,
     -     -0.1987d0,-0.1983d0,-0.1979d0,
     -     -0.1976d0,-0.1972d0,
     -     -0.1968d0,-0.1965d0,-0.1961d0,
     -     -0.1957d0,-0.1954d0,
     -     -0.195d0,-0.1946d0,-0.1943d0,
     -     -0.1939d0,-0.1935d0,
     -     -0.1932d0,-0.19283237985429658d0,
     -     -0.1925d0,
     -     -0.1921d0,-0.1918d0,-0.1914d0,
     -     -0.1911d0,-0.1907d0,
     -     -0.1904d0,-0.19d0,-0.1897d0,
     -     -0.1893d0,-0.189d0,
     -     -0.1886d0,-0.1883d0,-0.1879d0,
     -     -0.1876d0,-0.1872d0,
     -     -0.1869d0,-0.1866d0,-0.1862d0,
     -     -0.1859d0,-0.1855d0,
     -     -0.1852d0,-0.1849d0,-0.1845d0,
     -     -0.1842d0,-0.1839d0,
     -     -0.1835d0,-0.1832d0,-0.1829d0,
     -     -0.1825d0,-0.1822d0,
     -     -0.1819d0,-0.1815d0,-0.1812d0,
     -     -0.1809d0,-0.1806d0,
     -     -0.1802d0,-0.1799d0,-0.1796d0,
     -     -0.1793d0,-0.179d0,
     -     -0.1786d0,-0.1783d0,-0.178d0,
     -     -0.1777d0,-0.1774d0,
     -     -0.1771d0,-0.1767d0,-0.1764d0,
     -     -0.1761d0,-0.1758d0,
     -     -0.1755d0,-0.1752d0,-0.1749d0,
     -     -0.1746d0,-0.1743d0,
     -     -0.174d0,-0.1736d0,-0.1733d0,
     -     -0.173d0,-0.1727d0,
     -     -0.1724d0,-0.1721d0,-0.1718d0,
     -     -0.1715d0,-0.1712d0,
     -     -0.1709d0,-0.1706d0,-0.1703d0,
     -     -0.17d0,-0.1697d0,
     -     -0.1694d0,-0.1692d0,-0.1689d0,
     -     -0.1686d0,-0.1683d0,
     -     -0.168d0,-0.1677d0,-0.1674d0,
     -     -0.1671d0,-0.1668d0,
     -     -0.1665d0,-0.1663d0,-0.166d0,
     -     -0.1657d0,-0.1654d0,
     -     -0.1651d0,-0.1648d0,-0.1646d0,
     -     -0.1643d0,-0.164d0,
     -     -0.1637d0,-0.1634d0,-0.1632d0,
     -     -0.1629d0,-0.1626d0,
     -     -0.1623d0,-0.162d0,-0.1618d0,
     -     -0.1615d0,-0.1612d0,
     -     -0.1609d0,-0.1607d0,-0.1604d0,
     -     -0.1601d0,-0.1599d0,
     -     -0.1596d0,-0.1593d0,-0.1591d0,
     -     -0.1588d0,-0.1585d0,
     -     -0.1583d0,-0.158d0,-0.1577d0,
     -     -0.1575d0,-0.1572d0,
     -     -0.1569d0,-0.1567d0,-0.1564d0,
     -     -0.1562d0,-0.1559d0,
     -     -0.1556d0,-0.1554d0,-0.1551d0,
     -     -0.1549d0,-0.1546d0,
     -     -0.1543d0,-0.1541d0,-0.1538d0,
     -     -0.1536d0,-0.1533d0,
     -     -0.1531d0,-0.1528d0,-0.1526d0,
     -     -0.1523d0,-0.1521d0,
     -     -0.1518d0,-0.1516d0,-0.1513d0,
     -     -0.1511d0,-0.1508d0,
     -     -0.1506d0,-0.1503d0,-0.1501d0,
     -     -0.1498d0,-0.1496d0,
     -     -0.1493d0,-0.1491d0,-0.1489d0,
     -     -0.1486d0,-0.1484d0,
     -     -0.1481d0,-0.1479d0,-0.1477d0,
     -     -0.1474d0,-0.1472d0,
     -     -0.1469d0,-0.1467d0,-0.1465d0,
     -     -0.1462d0,-0.146d0,
     -     -0.1458d0,-0.1455d0,-0.1453d0,
     -     -0.1451d0,-0.1448d0,
     -     -0.1446d0,-0.1444d0,-0.1441d0,
     -     -0.1439d0,-0.1437d0,
     -     -0.1434d0,-0.1432d0,-0.143d0,
     -     -0.1428d0,-0.1425d0,
     -     -0.1423d0,-0.1421d0,-0.1418d0,
     -     -0.1416d0,-0.1414d0,
     -     -0.1412d0,-0.141d0,-0.1407d0,
     -     -0.1405d0,-0.1403d0,
     -     -0.1401d0,-0.1398d0,-0.1396d0,
     -     -0.1394d0,-0.1392d0,
     -     -0.139d0,-0.1387d0,-0.1385d0,
     -     -0.1383d0,-0.1381d0,
     -     -0.1379d0,-0.1377d0,-0.1374d0,
     -     -0.1372d0,-0.137d0,
     -     -0.1368d0,-0.1366d0,-0.1364d0,
     -     -0.1362d0,-0.136d0,
     -     -0.1357d0,-0.1355d0,-0.1353d0,
     -     -0.1351d0,-0.1349d0,
     -     -0.1347d0,-0.1345d0,-0.1343d0,
     -     -0.1341d0,-0.1339d0,
     -     -0.1337d0,-0.1335d0,-0.1332d0,
     -     -0.133d0,-0.1328d0,
     -     -0.1326d0,-0.1324d0,-0.1322d0,
     -     -0.132d0,-0.1318d0,
     -     -0.1316d0,-0.1314d0,-0.1312d0,
     -     -0.131d0,-0.1308d0,
     -     -0.1306d0,-0.1304d0,-0.1302d0,
     -     -0.13d0,-0.1298d0,
     -     -0.1296d0,-0.1294d0,-0.1292d0,
     -     -0.129d0,-0.1288d0,
     -     -0.1286d0,-0.1285d0,-0.1283d0,
     -     -0.1281d0,-0.1279d0,
     -     -0.1277d0,-0.1275d0,-0.1273d0,
     -     -0.1271d0,-0.1269d0,
     -     -0.1267d0,-0.1265d0,-0.1263d0,
     -     -0.1262d0,-0.126d0,
     -     -0.1258d0,-0.1256d0,-0.1254d0,
     -     -0.1252d0,-0.125d0,
     -     -0.1248d0,-0.1247d0,-0.1245d0,
     -     -0.1243d0,-0.1241d0,
     -     -0.1239d0,-0.1237d0,-0.1236d0,
     -     -0.1234d0,-0.1232d0,
     -     -0.123d0,-0.1228d0,-0.1226d0,
     -     -0.1225d0,-0.1223d0,
     -     -0.1221d0,-0.1219d0,-0.1217d0,
     -     -0.1216d0,-0.1214d0,
     -     -0.1212d0,-0.121d0,-0.1208d0,
     -     -0.1207d0,-0.1205d0,
     -     -0.1203d0,-0.1201d0,-0.12d0,
     -     -0.1198d0,-0.1196d0,
     -     -0.1194d0,-0.1193d0,-0.1191d0,
     -     -0.1189d0,-0.1188d0,
     -     -0.1186d0,-0.1184d0,-0.1182d0,
     -     -0.1181d0,-0.1179d0,
     -     -0.1177d0,-0.1176d0,-0.1174d0,
     -     -0.1172d0,-0.117d0,
     -     -0.1169d0,-0.1167d0,-0.1165d0
     -     ,-0.1164d0,-0.1162d0,
     -     -0.116d0,-0.1159d0,-0.1157d0,
     -     -0.1155d0,-0.1154d0,
     -     -0.1152d0,-0.115d0,-0.1149d0,
     -     -0.1147d0,-0.1146d0,
     -     -0.1144d0,-0.1142d0,-0.1141d0,
     -     -0.1139d0,-0.1137d0,
     -     -0.1136d0,-0.1134d0,-0.1133d0,
     -     -0.1131d0,-0.1129d0,
     -     -0.1128d0,-0.1126d0,-0.1125d0,
     -     -0.1123d0,-0.1121d0,
     -     -0.112d0,-0.1118d0,-0.1117d0,
     -     -0.1115d0,-0.1114d0,
     -     -0.1112d0,-0.111d0,-0.1109d0,
     -     -0.1107d0,-0.1106d0,
     -     -0.1104d0,-0.1103d0,-0.1101d0,
     -     -0.11d0,-0.1098d0,
     -     -0.1096d0,-0.1095d0,-0.1093d0,
     -     -0.1092d0,-0.109d0,
     -     -0.1089d0,-0.1087d0,-0.1086d0,
     -     -0.1084d0,-0.1083d0,
     -     -0.1081d0,-0.108d0,-0.1078d0,
     -     -0.1077d0,-0.1075d0,
     -     -0.1074d0,-0.1072d0,-0.1071d0,
     -     -0.1069d0,-0.1068d0,
     -     -0.1066d0,-0.1065d0,-0.1064d0,
     -     -0.1062d0,-0.1061d0,
     -     -0.1059d0,-0.1058d0,-0.1056d0,
     -     -0.1055d0,-0.1053d0,
     -     -0.1052d0,-0.1051d0,-0.1049d0,
     -     -0.1048d0,-0.1046d0,
     -     -0.1045d0,-0.1043d0,-0.1042d0,
     -     -0.1041d0,-0.1039d0,
     -     -0.1038d0,-0.1036d0,-0.1035d0,
     -     -0.1034d0,-0.1032d0,
     -     -0.1031d0,-0.1029d0,-0.1028d0,
     -     -0.1027d0,-0.1025d0,
     -     -0.1024d0,-0.1022d0,-0.1021d0,
     -     -0.102d0,-0.1018d0,
     -     -0.1017d0,-0.1016d0,-0.1014d0,
     -     -0.1013d0,-0.1011d0,
     -     -0.101d0,-0.1009d0,-0.1007d0,
     -     -0.1006d0,-0.1005d0,
     -     -0.1003d0,-0.1002d0,-0.1001d0,
     -     -0.09994d0,-0.0998d0,
     -     -0.09967d0,-0.09954d0,
     -     -0.09941d0,-0.09928d0,
     -     -0.09914d0,-0.09901d0,
     -     -0.09888d0,-0.09875d0,
     -     -0.09862d0,-0.09849d0,
     -     -0.09836d0,
     -     -0.09822885030274536d0,
     -     -0.0981d0,-0.09797d0,
     -     -0.09784d0,-0.09771d0,
     -     -0.09758d0,-0.09746d0/

      if ((mhiggs.le.20).or.(mhiggs.ge.1500)) then
         ReA1 = 0.d0
         ImA1 = 0.d0
         return
      end if

      i2=-100000
      do i1 = 0,1480
         if (((i1+20).Le.mhiggs).And.((i1+21).Ge.mhiggs)) i2 = i1
      end do
      if (i2.eq.-100000) then
         write(*,*) 'SusHi error in CalcA1MW'
         stop
      endif
      
      ReA1 = (realvalues(i2+2) - realvalues(i2+1))
     &     * (mhiggs - i2 - 20.D0) + realvalues(i2+1)

      ImA1 = (imvalues(i2+2) - imvalues(i2+1))
     &     * (mhiggs - i2 - 20.D0) + imvalues(i2+1)

      end

C-}}}
C-{{{ subroutine CalcA1MZ

      subroutine CalcA1MZ(mhiggs, ReA1, ImA1)
!--------------------------------------------------------
!This routine calculates the real and imaginary part
!of A1 taken from hep-ph/0404071 and 1007.1891.
!The grid is obtained in the complex mass scheme
!using m_Z = 91.1876GeV and Gamma_Z = 2.4952GeV.
!October 2012 - S. Liebler
!--------------------------------------------------------
      implicit none
      double precision mhiggs, ReA1, ImA1

      integer i1, i2
      double precision realvalues(1481), imvalues(1481)

!     imaginary part
!     stepsize: real values
	data realvalues /-0.02429d0,-0.02681d0,
     -	    -0.02945d0,-0.03223d0,
     -	    -0.03514d0,-0.03817d0,
     -	    -0.04134d0,-0.04465d0,
     -	    -0.04808d0,-0.05166d0,
     -	    -0.05537d0,-0.05922d0,
     -	    -0.0632d0,-0.06733d0,
     -	    -0.0716d0,-0.07602d0,-0.08057d0,
     -	    -0.08528d0,-0.09013316401843362d0,
     -	    -0.09514d0,
     -	    -0.1003d0,-0.1056d0,-0.1111d0,
     -	    -0.1167d0,-0.1225d0,
     -	    -0.1284d0,-0.1345d0,-0.1408d0,
     -	    -0.1472d0,-0.1539d0,
     -	    -0.1606d0,-0.1676d0,-0.1748d0,
     -	    -0.1821d0,-0.1896d0,
     -	    -0.1973d0,-0.2052d0,-0.2133d0,
     -	    -0.2216d0,-0.2301d0,
     -	    -0.2388d0,-0.2477d0,-0.2568d0,
     -	    -0.2661d0,-0.2757d0,
     -	    -0.2855d0,-0.2955d0,-0.3058d0,
     -	    -0.3163d0,-0.327d0,
     -	    -0.338d0,-0.3493d0,-0.3608d0,
     -	    -0.3726d0,-0.3847d0,
     -	    -0.3971d0,-0.4098d0,-0.4227d0,
     -	    -0.436d0,-0.4496d0,
     -	    -0.4635d0,-0.4778d0,-0.4924d0,
     -	    -0.5074d0,-0.5227d0,
     -	    -0.5384d0,-0.5545d0,-0.5711d0,
     -	    -0.588d0,-0.6054d0,
     -	    -0.6233d0,-0.6416d0,-0.6604d0,
     -	    -0.6798d0,-0.6996d0,
     -	    -0.7201d0,-0.7412d0,-0.7628d0,
     -	    -0.7852d0,-0.8082d0,
     -	    -0.8318d0,-0.8562d0,-0.8814d0,
     -	    -0.9072d0,-0.9338d0,
     -	    -0.9613d0,-0.9894d0,-1.018d0,
     -	    -1.048d0,-1.079d0,-1.11d0,
     -	    -1.143d0,-1.176d0,-1.21d0,-1.245d0,
     -	    -1.281d0,-1.317d0,
     -	    -1.355d0,-1.393d0,-1.433d0,-1.473d0,
     -	    -1.514d0,-1.556d0,
     -	    -1.6d0,-1.644d0,-1.689d0,-1.734d0,
     -	    -1.781d0,-1.829d0,
     -	    -1.878d0,-1.928d0,-1.978d0,-2.03d0,
     -	    -2.083d0,-2.137d0,
     -	    -2.191d0,-2.247d0,-2.304d0,-2.362d0,
     -	    -2.421d0,-2.481d0,
     -	    -2.542d0,-2.605d0,-2.668d0,-2.733d0,
     -	    -2.798d0,-2.865d0,
     -	    -2.933d0,-3.003d0,-3.074d0,-3.145d0,
     -	    -3.219d0,-3.293d0,
     -	    -3.369d0,-3.446d0,-3.525d0,
     -	    -3.605d0,-3.687d0,-3.77d0,
     -	    -3.854d0,-3.94d0,-4.028d0,
     -	    -4.117d0,-4.208d0,-4.3d0,
     -	    -4.394d0,-4.489d0,-4.586d0,
     -	    -4.683d0,-4.782d0,-4.881d0,
     -	    -4.98d0,-5.078d0,-5.175d0,
     -	    -5.268d0,-5.354d0,-5.43d0,
     -	    -5.487d0,-5.514d0,-5.49d0,
     -	    -5.378d0,-5.116d0,-4.637d0,
     -	    -3.955d0,-3.208d0,-2.522d0,
     -	    -1.936d0,-1.441d0,-1.022d0,
     -	    -0.6615d0,-0.3483d0,
     -	    -0.07272d0,0.1721d0,0.3917d0,
     -	    0.59d0,0.7704d0,0.9354d0,1.087d0,
     -	    1.227d0,1.357d0,1.478d0,
     -	    1.591d0,1.696d0,1.795d0,1.888d0,
     -	    1.976d0,2.059d0,2.138d0,
     -	    2.212d0,2.283d0,2.35d0,2.414d0,
     -	    2.475d0,2.533d0,2.588d0,
     -	    2.641d0,2.692d0,2.74d0,2.787d0,
     -	    2.831d0,2.874d0,2.915d0,
     -	    2.955d0,2.993d0,3.029d0,3.065d0,
     -	    3.098d0,3.131d0,3.163d0,
     -	    3.193d0,3.222d0,3.25d0,3.278d0,
     -	    3.304d0,3.329d0,3.354d0,
     -	    3.378d0,3.4d0,3.423d0,3.444d0,
     -	    3.465d0,3.485d0,3.504d0,
     -	    3.523d0,3.541d0,3.559d0,3.576d0,
     -	    3.593d0,3.609d0,3.624d0,
     -	    3.639d0,3.654d0,3.668d0,3.682d0,
     -	    3.695d0,3.708d0,3.72d0,
     -	    3.732d0,3.744d0,3.756d0,3.767d0,
     -	    3.777d0,3.788d0,3.798d0,
     -	    3.807d0,3.817d0,3.826d0,3.835d0,
     -	    3.844d0,3.852d0,3.86d0,
     -	    3.868d0,3.876d0,3.883d0,3.89d0,
     -	    3.897d0,3.904d0,3.911d0,
     -	    3.917d0,3.923d0,3.929d0,3.935d0,
     -	    3.94d0,3.946d0,3.951d0,
     -	    3.956d0,3.961d0,3.966d0,3.97d0,
     -	    3.975d0,3.979d0,3.983d0,
     -	    3.987d0,3.991d0,3.995d0,3.999d0,
     -	    4.002d0,4.006d0,4.009d0,
     -	    4.012d0,4.015d0,4.018d0,4.021d0,
     -	    4.024d0,4.026d0,4.029d0,
     -	    4.031d0,4.034d0,4.036d0,4.038d0,
     -	    4.04d0,4.042d0,4.044d0,
     -	    4.046d0,4.048d0,4.049d0,4.051d0,
     -	    4.053d0,4.054d0,4.055d0,
     -	    4.057d0,4.058d0,4.059d0,4.06d0,
     -	    4.061d0,4.062d0,4.063d0,
     -	    4.064d0,4.065d0,4.066d0,4.067d0,
     -	    4.067d0,4.068d0,4.068d0,
     -	    4.069d0,4.069d0,4.07d0,4.07d0,
     -	    4.070606477462053d0,
     -	    4.071d0,4.071d0,4.071d0,4.072d0,
     -	    4.072d0,4.072d0,4.072d0,
     -	    4.072d0,4.072d0,4.072d0,4.072d0,
     -	    4.072d0,4.071d0,4.071d0,
     -	    4.071d0,4.071d0,4.071d0,4.07d0,
     -	    4.07d0,4.07d0,4.069d0,
     -	    4.069d0,4.068d0,4.068d0,4.067d0,
     -	    4.067d0,4.066d0,4.066d0,
     -	    4.065d0,4.065d0,4.064d0,4.063d0,
     -	    4.063d0,4.062d0,4.061d0,
     -	    4.061d0,4.06d0,4.059d0,4.058d0,
     -	    4.058d0,4.057d0,4.056d0,
     -	    4.055d0,4.054d0,4.053d0,4.053d0,
     -	    4.052d0,4.051d0,4.05d0,
     -	    4.049d0,4.048d0,4.047d0,4.046d0,
     -	    4.045d0,4.044d0,4.043d0,
     -	    4.042d0,4.041d0,4.04d0,4.039d0,
     -	    4.038d0,4.037d0,4.036d0,
     -	    4.035d0,4.034d0,4.032d0,4.031d0,
     -	    4.03d0,4.029d0,4.028d0,
     -	    4.027d0,4.026d0,4.024d0,4.023d0,
     -	    4.022d0,4.021d0,4.02d0,
     -	    4.019d0,4.017d0,4.016d0,4.015d0,
     -	    4.014d0,4.013d0,4.011d0,
     -	    4.01d0,4.009d0,4.008d0,4.006d0,
     -	    4.005d0,4.004d0,4.003d0,
     -	    4.001d0,4.d0,3.999d0,3.998d0,
     -	    3.996d0,3.995d0,3.994d0,
     -	    3.992d0,3.991d0,3.99d0,3.989d0,
     -	    3.987d0,3.986d0,3.985d0,
     -	    3.983d0,3.982d0,3.981d0,3.979d0,
     -	    3.978d0,3.977d0,3.976d0,
     -	    3.974d0,3.973d0,3.972d0,3.97d0,
     -	    3.969d0,3.968d0,3.966d0,
     -	    3.965d0,3.963685886505661d0,
     -	    3.962d0,3.961d0,3.96d0,
     -	    3.958d0,3.957d0,3.956d0,
     -	    3.954d0,3.953d0,3.952d0,
     -	    3.95d0,
     -	    3.949d0,3.948d0,3.946d0,
     -	    3.945d0,3.944d0,3.943d0,
     -	    3.941d0,
     -	    3.94d0,3.939d0,3.937d0,
     -	    3.936d0,3.935d0,3.933d0,3.932d0,
     -	    3.931d0,3.929d0,3.928d0,
     -	    3.927d0,3.925d0,3.924d0,3.923d0,
     -	    3.921d0,3.92d0,3.919d0,3.917d0,
     -	    3.916d0,3.915d0,3.914d0,
     -	    3.912d0,3.911d0,3.91d0,
     -	    3.908d0,3.907d0,3.906d0,
     -	    3.904d0,
     -	    3.903d0,3.902d0,3.901d0,
     -	    3.899d0,3.898d0,3.897d0,3.895d0,
     -	    3.894d0,3.893d0,3.892d0,
     -	    3.89d0,3.889d0,3.888d0,3.887d0,
     -	    3.885d0,3.884d0,
     -	    3.883d0,3.881d0,3.88d0,
     -	    3.879d0,3.878d0,
     -	    3.876d0,3.875d0,3.874d0,
     -	    3.873d0,3.871d0,3.87d0,
     -	    3.869d0,
     -	    3.868d0,3.866d0,3.865d0,
     -	    3.864d0,3.863d0,3.862d0,3.86d0,
     -	    3.859d0,3.858d0,
     -	    3.857d0,3.855d0,
     -	    3.854d0,3.853d0,3.852d0,
     -	    3.851d0,3.849d0,
     -	    3.848d0,3.847d0,
     -	    3.846d0,3.845d0,3.843d0,
     -	    3.842d0,3.841d0,
     -	    3.84d0,3.839d0,
     -	    3.837d0,3.836d0,3.835d0,
     -	    3.834d0,3.833d0,
     -	    3.832d0,3.83d0,
     -	    3.829d0,3.828d0,3.827d0,
     -	    3.826d0,3.825d0,
     -	    3.823d0,3.822d0,
     -	    3.821d0,3.82d0,3.819d0,
     -	    3.818d0,3.816d0,
     -	    3.815d0,3.814d0,
     -	    3.813d0,3.812d0,3.811d0,
     -	    3.81d0,3.809d0,3.807d0,
     -	    3.806d0,3.805d0,
     -	    3.804d0,3.803d0,
     -	    3.802d0,3.801d0,
     -	    3.8d0,3.799d0,
     -	    3.797d0,3.796d0,3.795d0,
     -	    3.794d0,3.793d0,
     -	    3.792d0,3.791d0,
     -	    3.79d0,3.789d0,3.788d0,
     -	    3.787d0,3.786d0,
     -	    3.784d0,3.783d0,
     -	    3.782d0,3.781d0,3.78d0,
     -	    3.779d0,3.778d0,
     -	    3.777d0,3.776d0,
     -	    3.775d0,3.774d0,3.773d0,
     -	    3.772d0,3.771d0,
     -	    3.77d0,3.769d0,
     -	    3.768d0,3.767d0,3.766d0,
     -	    3.765d0,3.764d0,
     -	    3.763d0,3.762d0,
     -	    3.761d0,3.76d0,3.759d0,
     -	    3.758d0,3.757d0,3.756d0,
     -	    3.755d0,3.754d0,
     -	    3.753d0,3.752d0,
     -	    3.751d0,3.75d0,
     -	    3.749d0,3.748d0,
     -	    3.747d0,3.746d0,3.745d0,
     -	    3.744d0,3.743d0,
     -	    3.742d0,3.741d0,
     -	    3.74d0,3.739d0,3.738d0,
     -	    3.737d0,3.736d0,
     -	    3.735d0,3.734d0,
     -	    3.733d0,3.732d0,
     -	    3.731d0,
     -	    3.73d0,3.729d0,
     -	    3.728d0,3.728d0,
     -	    3.727d0,3.726d0,3.725d0,
     -	    3.724d0,3.723d0,
     -	    3.722d0,3.721d0,
     -	    3.72d0,3.719d0,3.718d0,
     -	    3.717d0,3.716d0,
     -	    3.716d0,3.715d0,
     -	    3.714d0,3.713d0,3.712d0,
     -	    3.711d0,3.71d0,
     -	    3.709d0,3.708d0,
     -	    3.708d0,3.707d0,3.706d0,
     -	    3.705d0,3.704d0,
     -	    3.703d0,3.702d0,
     -	    3.701d0,3.701d0,3.7d0,
     -	    3.699d0,3.698d0,
     -	    3.697d0,3.696d0,
     -	    3.695d0,3.695d0,3.694d0,
     -	    3.693d0,3.692d0,
     -	    3.691d0,3.69d0,
     -	    3.689d0,3.689d0,3.688d0,
     -	    3.687d0,3.686d0,
     -	    3.685d0,3.684d0,
     -	    3.684d0,3.683d0,3.682d0,
     -	    3.681d0,3.68d0,
     -	    3.68d0,3.679d0,
     -	    3.678d0,3.677d0,3.676d0,
     -	    3.676d0,3.675d0,
     -	    3.674d0,3.673d0,
     -	    3.672d0,3.672d0,3.671d0,
     -	    3.67d0,3.669d0,
     -	    3.668d0,3.668d0,
     -	    3.667d0,3.666d0,3.665d0,
     -	    3.664d0,3.664d0,
     -	    3.663d0,3.662d0,
     -	    3.661d0,3.661d0,3.66d0,
     -	    3.659d0,3.658d0,
     -	    3.658d0,3.657d0,
     -	    3.656d0,3.655d0,3.655d0,
     -	    3.654d0,3.653d0,
     -	    3.652d0,3.652d0,
     -	    3.651d0,3.65d0,
     -	    3.649d0,
     -	    3.649d0,3.648d0,
     -	    3.647d0,3.646d0,
     -	    3.646d0,3.645d0,3.644d0,
     -	    3.643d0,3.643d0,
     -	    3.642d0,3.641d0,
     -	    3.641d0,3.64d0,3.639d0,
     -	    3.638d0,3.638d0,
     -	    3.637d0,3.636d0,
     -	    3.636d0,3.635d0,3.634d0,
     -	    3.633d0,3.633d0,
     -	    3.632d0,3.631d0,
     -	    3.631d0,3.63d0,3.629d0,
     -	    3.629d0,3.628d0,
     -	    3.627d0,3.627d0,
     -	    3.626d0,3.625d0,
     -	    3.624d0,
     -	    3.624d0,3.623d0,
     -	    3.622d0,3.622d0,
     -	    3.621d0,3.62d0,3.62d0,
     -	    3.619d0,3.618d0,
     -	    3.618d0,3.617d0,
     -	    3.616d0,3.616d0,3.615d0,
     -	    3.614d0,3.614d0,
     -	    3.613d0,3.613d0,
     -	    3.612d0,
     -	    3.611211152498204d0,
     -	    3.611d0,3.61d0,3.609d0,3.609d0,
     -	    3.608d0,3.607d0,
     -	    3.607d0,3.606d0,
     -	    3.605d0,3.605d0,
     -	    3.604d0,
     -	    3.604d0,3.603d0,
     -	    3.602d0,3.602d0,3.601d0,3.6d0,3.6d0,
     -	    3.599d0,3.599d0,
     -	    3.598d0,3.597d0,3.597d0,3.596d0,3.595d0,
     -	    3.595d0,3.594d0,
     -	    3.594d0,3.593d0,
     -	    3.592d0,3.592d0,3.591d0,
     -	    3.591d0,3.59d0,3.589d0,
     -	    3.589d0,3.588d0,
     -	    3.588d0,3.587d0,
     -	    3.587d0,3.586d0,
     -	    3.585d0,3.585d0,3.584d0,
     -	    3.584d0,3.583d0,
     -	    3.582d0,3.582d0,
     -	    3.581d0,3.581d0,3.58d0,
     -	    3.58d0,3.579d0,
     -	    3.578d0,3.578d0,3.577d0,
     -	    3.577d0,3.576d0,3.576d0,3.575d0,
     -	    3.574d0,3.574d0,3.573d0,
     -	    3.573d0,3.572d0,3.572d0,3.571d0,
     -	    3.571d0,3.57d0,3.569d0,
     -	    3.569d0,3.568d0,3.568d0,3.567d0,
     -	    3.567d0,3.566d0,3.566d0,
     -	    3.565d0,3.565d0,
     -	    3.564d0,3.563d0,
     -	    3.563d0,3.562d0,3.562d0,
     -	    3.561d0,3.561d0,3.56d0,3.56d0,
     -	    3.559d0,3.559d0,
     -	    3.558d0,3.558d0,3.557d0,
     -	    3.557d0,3.556d0,
     -	    3.556d0,3.555d0,3.555d0,
     -	    3.554d0,3.554d0,3.553d0,3.553d0,
     -	    3.552d0,3.551d0,3.551d0,
     -	    3.55d0,3.55d0,3.549d0,
     -	    3.549d0,
     -	    3.548d0,3.548d0,3.547d0,
     -	    3.547d0,3.546d0,
     -	    3.546d0,3.545d0,
     -	    3.545d0,3.544d0,3.544d0,
     -	    3.544d0,3.543d0,
     -	    3.543d0,3.542d0,
     -	    3.542d0,3.541d0,3.541d0,
     -	    3.54d0,3.54d0,3.539d0,
     -	    3.539d0,
     -	    3.538d0,3.538d0,3.537d0,
     -	    3.537d0,3.536d0,
     -	    3.536d0,3.535d0,
     -	    3.535d0,3.534d0,3.534d0,
     -	    3.533d0,3.533d0,
     -	    3.533d0,3.532d0,
     -	    3.532d0,3.531d0,
     -	    3.531d0,3.53d0,
     -	    3.529742882462595d0,
     -	    3.529d0,3.529d0,3.528d0,
     -	    3.528d0,3.527d0,
     -	    3.527d0,3.527d0,
     -	    3.526d0,3.525647804228772d0,
     -	    3.525d0,3.525d0,3.524d0,
     -	    3.524d0,3.523d0,3.523d0,
     -	    3.523d0,3.522d0,
     -	    3.522d0,3.521d0,
     -	    3.521d0,3.52d0,3.52d0,
     -	    3.519d0,3.519d0,
     -	    3.519d0,3.518d0,
     -	    3.518d0,3.517d0,3.517d0,
     -	    3.516d0,3.516d0,3.516d0,3.515d0,
     -	    3.515d0,3.514d0,3.514d0,
     -	    3.513d0,3.513d0,
     -	    3.513d0,3.512d0,
     -	    3.512d0,3.511d0,3.511d0,
     -	    3.51d0,3.51d0,3.51d0,3.509d0,
     -	    3.509d0,3.508d0,3.508d0,
     -	    3.508d0,3.507d0,
     -	    3.507d0,3.506d0,
     -	    3.506d0,3.506d0,3.505d0,
     -	    3.505d0,3.504d0,
     -	    3.504d0,3.503d0,
     -	    3.503d0,3.503d0,
     -	    3.502d0,3.502d0,
     -	    3.501d0,3.501d0,3.501d0,
     -	    3.5d0,3.5d0,3.5d0,
     -	    3.499d0,3.499d0,
     -	    3.498d0,3.498d0,
     -	    3.498d0,
     -	    3.497d0,3.497d0,
     -	    3.496d0,3.496d0,
     -	    3.496d0,3.495d0,
     -	    3.495d0,
     -	    3.494d0,3.494d0,
     -	    3.494d0,3.493d0,
     -	    3.493d0,3.493d0,
     -	    3.492d0,
     -	    3.492d0,3.491d0,
     -	    3.491d0,3.491d0,
     -	    3.49d0,3.49d0,3.49d0,
     -	    3.489d0,3.489d0,
     -	    3.488d0,3.488d0,
     -	    3.488d0,3.487d0,
     -	    3.487d0,
     -	    3.487d0,3.486d0,
     -	    3.486d0,3.485d0,
     -	    3.485d0,3.485d0,
     -	    3.484d0,
     -	    3.484d0,3.484d0,
     -	    3.483d0,3.483d0,
     -	    3.483d0,3.482d0,
     -	    3.482d0,
     -	    3.481d0,3.481d0,
     -	    3.481d0,3.48d0,
     -	    3.48d0,3.48d0,
     -	    3.479d0,
     -	    3.479d0,3.479d0,
     -	    3.478d0,3.478d0,
     -	    3.478d0,3.477d0,
     -	    3.477d0,
     -	    3.477d0,3.476d0,
     -	    3.476d0,3.476d0,
     -	    3.475d0,3.475d0,
     -	    3.474d0,
     -	    3.474d0,3.474d0,3.473d0,
     -	    3.473d0,3.473d0,
     -	    3.472d0,3.472d0,
     -	    3.472d0,3.471d0,3.471d0,
     -	    3.471d0,3.47d0,
     -	    3.47d0,3.47d0,
     -	    3.469d0,3.469d0,
     -	    3.469d0,3.468d0,3.468d0,
     -	    3.468d0,3.467d0,
     -	    3.467d0,3.467d0,3.466d0,
     -	    3.466d0,3.466d0,
     -	    3.465d0,3.465d0,
     -	    3.465d0,3.464d0,
     -	    3.464d0,3.464d0,
     -	    3.464d0,3.463d0,
     -	    3.463d0,
     -	    3.463d0,3.462d0,
     -	    3.462d0,3.462d0,
     -	    3.461d0,3.461d0,3.461d0,
     -	    3.46d0,3.46d0,
     -	    3.46d0,3.459d0,
     -	    3.459d0,3.459d0,
     -	    3.458d0,
     -	    3.458d0,3.458d0,
     -	    3.458d0,3.457d0,
     -	    3.457d0,3.457d0,
     -	    3.456d0,
     -	    3.456d0,3.456d0,
     -	    3.455d0,3.455d0,
     -	    3.455d0,3.454d0,3.454d0,
     -	    3.454d0,3.454d0,
     -	    3.453d0,3.453d0,
     -	    3.453d0,3.452d0,
     -	    3.452d0,
     -	    3.452d0,3.451d0,
     -	    3.451d0,3.451d0,
     -	    3.451d0,3.45d0,
     -	    3.45d0,
     -	    3.45d0,3.449d0,
     -	    3.449d0,3.449d0,
     -	    3.449d0,3.448d0,3.448d0,
     -	    3.448d0,3.447d0,
     -	    3.447d0,3.447d0,
     -	    3.446d0,3.446d0,
     -	    3.446d0,
     -	    3.446d0,3.445d0,
     -	    3.445d0,3.445d0,
     -	    3.444d0,3.444d0,3.444d0,
     -	    3.444d0,3.443d0,
     -	    3.443d0,3.443d0,
     -	    3.443d0,3.442d0,3.442d0,
     -	    3.442d0,3.441d0,
     -	    3.441d0,3.441d0,
     -	    3.441d0,3.44d0,3.44d0,
     -	    3.44d0,3.439d0,
     -	    3.439d0,3.439d0,
     -	    3.439d0,3.438d0,3.438d0,
     -	    3.438d0,3.438d0,
     -	    3.437d0,3.437d0,
     -	    3.437d0,3.436d0,3.436d0,
     -	    3.436d0,3.436d0,
     -	    3.435d0,3.435d0,
     -	    3.435d0,3.435d0,3.434d0,
     -	    3.434d0,3.434d0,
     -	    3.434d0,3.433d0,
     -	    3.433d0,3.433d0,3.432d0,
     -	    3.432d0,3.432d0,
     -	    3.432d0,3.431d0,
     -	    3.431d0,3.431d0,3.431d0,
     -	    3.43d0,3.43d0,
     -	    3.43d0,3.43d0,3.429d0,
     -	    3.429d0,3.429d0,
     -	    3.429d0,3.428d0,
     -	    3.428d0,3.428d0,
     -	    3.428d0,3.427d0,3.427d0,
     -	    3.427d0,3.427d0,
     -	    3.426d0,3.426d0,
     -	    3.426d0,3.426d0,3.425d0,
     -	    3.425d0,3.425d0,
     -	    3.425d0,3.424d0,
     -	    3.424d0,3.424d0,3.424d0,
     -	    3.423d0,3.423d0,
     -	    3.423d0,3.423d0,
     -	    3.422d0,3.422d0,3.422d0,
     -	    3.422d0,3.421d0,
     -	    3.421d0,3.421d0,
     -	    3.421d0,3.42d0,3.42d0,
     -	    3.42d0,3.42d0,
     -	    3.419d0,3.419d0,
     -	    3.419d0,3.419d0,3.419d0,
     -	    3.418d0,3.418d0,
     -	    3.418d0,3.418d0,
     -	    3.417d0,3.417d0,3.417d0,
     -	    3.417d0,3.416d0,
     -	    3.416d0,3.416d0,
     -	    3.416d0,3.415d0,3.415d0,
     -	    3.415d0,3.415d0,
     -	    3.415d0,3.414d0,
     -	    3.414d0,3.414d0,3.414d0,
     -	    3.413d0,3.413d0,
     -	    3.413d0,3.413d0,
     -	    3.413d0,3.412d0,3.412d0,
     -	    3.412d0,3.412d0,
     -	    3.411d0,3.411d0,
     -	    3.411d0,3.411d0,3.411d0,
     -	    3.41d0,3.41d0,
     -	    3.41d0,3.41d0,
     -	    3.409d0,3.409d0,3.409d0,
     -	    3.409d0,3.409d0,
     -	    3.408d0,3.408d0,
     -	    3.408d0,3.408d0,3.407d0,
     -	    3.407d0,3.407d0,
     -	    3.407d0,3.407d0,
     -	    3.406d0,3.406d0,3.406d0,
     -	    3.406d0,3.405d0,
     -	    3.405d0,3.405d0,
     -	    3.405d0,3.405d0,3.404d0,
     -	    3.404d0,3.404d0,
     -	    3.404d0,3.404d0,
     -	    3.403d0,3.403d0,3.403d0,
     -	    3.403d0,3.403d0,
     -	    3.402d0,3.402d0,
     -	    3.402d0,3.402d0,3.401d0,
     -	    3.401d0,3.401d0,
     -	    3.401d0,3.401d0,
     -	    3.4d0,3.4d0,3.4d0,3.4d0,
     -	    3.4d0,3.399d0,3.399d0,
     -	    3.399d0,3.399d0,3.399d0,3.398d0,
     -	    3.398d0,3.398d0,
     -	    3.398d0,3.398d0,
     -	    3.397d0,3.397d0,
     -	    3.397d0,
     -	    3.397d0,3.397d0,
     -	    3.396d0,3.396d0,
     -	    3.396d0,3.396d0,
     -	    3.396d0,
     -	    3.395d0,3.395d0,
     -	    3.395d0,3.395d0,
     -	    3.395d0,3.394d0,3.394d0,
     -	    3.394d0,3.394d0,
     -	    3.394d0,3.393d0,
     -	    3.393d0,3.393d0,3.393d0,
     -	    3.393d0,3.393d0,
     -	    3.392d0,3.392d0,
     -	    3.392d0,3.392d0,3.392d0,
     -	    3.391d0,3.391d0,
     -	    3.391d0,3.391d0,
     -	    3.391d0,3.39d0,3.39d0,
     -	    3.39d0,3.39d0,3.39d0,
     -	    3.389d0,3.389d0,
     -	    3.389d0,3.389d0,
     -	    3.389d0,3.389d0,
     -	    3.388d0,3.388d0,
     -	    3.388d0,3.388d0,3.388d0,
     -	    3.387d0,3.387d0,
     -	    3.387d0,3.387d0,
     -	    3.387d0,3.387d0,3.386d0,
     -	    3.386d0,3.386d0,
     -	    3.386d0,3.386d0,
     -	    3.385d0,3.385d0,
     -	    3.385d0,
     -	    3.385d0,3.385d0,
     -	    3.385d0,3.384d0,
     -	    3.384d0,3.384d0,
     -	    3.384d0,
     -	    3.384d0,3.383d0,
     -	    3.383d0,3.383d0,
     -	    3.383d0,3.383d0,3.383d0,
     -	    3.382d0,3.382d0,
     -	    3.382d0,3.382d0,3.382d0,3.382d0,3.381d0,
     -	    3.381d0,3.381d0,
     -	    3.381d0,3.381d0,3.381d0,
     -	    3.38d0,3.38d0,
     -	    3.38d0,3.38d0,3.38d0,
     -	    3.379d0,3.379d0,
     -	    3.379d0,3.379d0,
     -	    3.379d0,3.379d0,3.378d0,
     -	    3.378d0,3.378d0,3.378d0,3.378d0,
     -	    3.378d0/


      data imvalues /-0.0006716d0,
     -      -0.0007421d0,-0.0008162d0,
     -      -0.0008942d0,-0.0009761d0,
     -      -0.001062d0,-0.001152d0,
     -      -0.001245d0,-0.001343d0,
     -      -0.001445d0,-0.001551d0,
     -      -0.001662d0,-0.001777d0,
     -      -0.001896d0,-0.00202d0,
     -      -0.002149d0,-0.002282d0,
     -      -0.00242d0,-0.002563d0,
     -      -0.002711d0,-0.002864d0,
     -      -0.003023d0,-0.003186d0,
     -      -0.003356d0,-0.00353d0,
     -      -0.003711d0,-0.003898d0,
     -      -0.0040902199726041985d0,
     -      -0.004289d0,-0.004494d0,
     -      -0.004706d0,-0.004924d0,
     -      -0.00515d0,-0.005382d0,
     -      -0.005622d0,-0.00587d0,
     -      -0.006125d0,-0.006388d0,
     -      -0.006659d0,-0.006939d0,
     -      -0.007228d0,-0.007526d0,
     -      -0.007833d0,-0.00815d0,
     -      -0.008476d0,-0.008814d0,
     -      -0.009162d0,-0.009521d0,
     -      -0.009892d0,-0.01027d0,
     -      -0.01067d0,-0.01108d0,
     -      -0.0115d0,-0.01194d0,
     -      -0.01239d0,-0.01285d0,
     -      -0.01333d0,-0.01383d0,
     -      -0.01435d0,-0.01488d0,
     -      -0.01543d0,-0.01601d0,
     -      -0.0166d0,-0.01722d0,
     -      -0.01786d0,-0.01852d0,
     -      -0.01922d0,-0.01994d0,
     -      -0.02069d0,-0.02147d0,
     -      -0.02229d0,-0.02315d0,
     -      -0.02405d0,-0.025d0,-0.02601d0,
     -      -0.02709d0,-0.02826d0,-0.02953d0,
     -      -0.03092802754645655d0,
     -      -0.03247d0,-0.03419d0,
     -      -0.03611d0,-0.03825d0,
     -      -0.04065d0,-0.04332d0,
     -      -0.04631d0,-0.04964d0,
     -      -0.05335d0,-0.05746d0,
     -      -0.06201d0,-0.06703d0,
     -      -0.07255d0,-0.07862d0,
     -      -0.08525d0,-0.09249d0,
     -      -0.1004d0,-0.1089d0,-0.1182d0,
     -      -0.1282d0,-0.139d0,-0.1507d0,
     -      -0.1632d0,-0.1765d0,
     -      -0.1909d0,-0.2062d0,-0.2225d0,
     -      -0.2399d0,-0.2585d0,
     -      -0.2781d0,-0.299d0,-0.3211d0,
     -      -0.3446d0,-0.3694d0,
     -      -0.3956d0,-0.4233d0,-0.4525d0,
     -      -0.4833d0,-0.5158d0,
     -      -0.55d0,-0.5861d0,-0.624d0,
     -      -0.6639d0,-0.7059d0,-0.75d0,
     -      -0.7964d0,-0.8452d0,-0.8964d0,
     -      -0.9503d0,-1.007d0,
     -      -1.066d0,-1.129d0,-1.195d0,
     -      -1.264d0,-1.337d0,-1.413d0,
     -      -1.494d0,-1.579d0,-1.669d0,
     -      -1.764d0,-1.864d0,-1.97d0,
     -      -2.082d0,-2.201d0,-2.328d0,
     -      -2.462d0,-2.605d0,-2.759d0,
     -      -2.923d0,-3.099d0,-3.288d0,
     -      -3.493d0,-3.716d0,-3.958d0,
     -      -4.224d0,-4.517d0,-4.842d0,
     -      -5.207d0,-5.618d0,-6.086d0,
     -      -6.622d0,-7.233d0,-7.904d0,
     -      -8.559d0,-9.053d0,-9.304d0,
     -      -9.359d0,-9.304d0,-9.193d0,
     -      -9.055d0,-8.907d0,-8.756d0,
     -      -8.607d0,-8.46d0,-8.317d0,
     -      -8.179d0,-8.046d0,-7.918d0,
     -      -7.794d0,-7.674d0,-7.559d0,
     -      -7.448d0,-7.34d0,-7.236d0,
     -      -7.136d0,-7.038d0,-6.944d0,
     -      -6.852d0,-6.763d0,-6.677d0,
     -      -6.592d0,-6.511d0,-6.431d0,
     -      -6.353d0,-6.278d0,-6.204d0,
     -      -6.132d0,-6.062d0,-5.993d0,
     -      -5.926d0,-5.861d0,-5.797d0,
     -      -5.734d0,-5.672d0,-5.612d0,
     -      -5.553d0,-5.496d0,-5.439d0,
     -      -5.384d0,-5.329d0,-5.276d0,
     -      -5.223d0,-5.172d0,-5.121d0,
     -      -5.072d0,-5.023d0,-4.975d0,
     -      -4.928d0,-4.882d0,-4.836d0,
     -      -4.792d0,-4.748d0,-4.704d0,
     -      -4.662d0,-4.62d0,-4.579d0,
     -      -4.538d0,-4.498d0,-4.459d0,
     -      -4.42d0,-4.382d0,-4.344d0,
     -      -4.307d0,-4.27d0,-4.234d0,
     -      -4.199d0,-4.164d0,-4.129d0,
     -      -4.095d0,-4.062d0,-4.029d0,
     -      -3.996d0,-3.964d0,-3.932d0,
     -      -3.901d0,-3.87d0,-3.839d0,
     -      -3.809d0,-3.779d0,-3.75d0,
     -      -3.721d0,-3.692d0,-3.664d0,
     -      -3.636d0,-3.609d0,-3.581d0,
     -      -3.555d0,-3.528d0,-3.502d0,
     -      -3.476d0,-3.45d0,-3.425d0,
     -      -3.4d0,-3.375d0,-3.351d0,
     -      -3.327d0,-3.303d0,-3.279d0,
     -      -3.256d0,-3.233d0,-3.21d0,
     -      -3.187d0,-3.165d0,-3.143d0,
     -      -3.121d0,-3.1d0,-3.078d0,
     -      -3.057d0,-3.036d0,-3.016d0,
     -      -2.995d0,-2.975d0,-2.955d0,
     -      -2.935d0,-2.916d0,-2.896d0,
     -      -2.877d0,-2.858d0,-2.84d0,
     -      -2.821d0,-2.803d0,-2.784d0,
     -      -2.766d0,-2.749d0,-2.731d0,
     -      -2.714d0,-2.696d0,-2.679d0,
     -      -2.6621485069246105d0,-2.645d0,
     -      -2.629d0,-2.612d0,
     -      -2.596d0,-2.58d0,-2.564d0,
     -      -2.548d0,-2.532d0,-2.517d0,
     -      -2.501d0,-2.486d0,-2.471d0,
     -      -2.456d0,-2.441d0,-2.427d0,
     -      -2.412d0,-2.398d0,-2.384d0,
     -      -2.369d0,-2.355d0,-2.342d0,
     -      -2.328d0,-2.314d0,-2.301d0,
     -      -2.287d0,-2.274d0,-2.261d0,
     -      -2.248d0,-2.235d0,-2.222d0,
     -      -2.21d0,-2.197d0,-2.185d0,
     -      -2.172d0,-2.16d0,-2.148d0,
     -      -2.136d0,-2.124d0,-2.112d0,
     -      -2.1d0,-2.089d0,-2.077d0,
     -      -2.066d0,-2.054d0,-2.043d0,
     -      -2.032d0,-2.021d0,-2.01d0,
     -      -1.999d0,-1.988d0,-1.978d0,
     -      -1.967d0,-1.957d0,-1.946d0,
     -      -1.936d0,-1.926d0,-1.915d0,
     -      -1.905d0,-1.895d0,-1.885d0,
     -      -1.876d0,-1.866d0,-1.856d0,
     -      -1.847d0,-1.837d0,-1.828d0,
     -      -1.818d0,-1.809d0,-1.8d0,
     -      -1.79d0,-1.781d0,-1.772d0,
     -      -1.763d0,-1.754d0,-1.746d0,
     -      -1.737d0,-1.728d0,-1.72d0,
     -      -1.711d0,-1.703d0,-1.694d0,
     -      -1.686d0,-1.677d0,-1.669d0,
     -      -1.661d0,-1.653d0,-1.645d0,
     -      -1.637d0,-1.629d0,-1.621d0,
     -      -1.613d0,-1.605d0,-1.598d0,
     -      -1.59d0,-1.583d0,-1.575d0,
     -      -1.568d0,-1.56d0,-1.553d0,
     -      -1.545d0,-1.538d0,-1.531d0,
     -      -1.524d0,-1.517d0,-1.51d0,
     -      -1.503d0,-1.496d0,-1.489d0,
     -      -1.482d0,-1.475d0,-1.468d0,
     -      -1.462d0,-1.455d0,-1.448d0,
     -      -1.442d0,-1.435d0,-1.429d0,
     -      -1.422d0,-1.416d0,-1.409d0,
     -      -1.403d0,-1.397d0,-1.391d0,
     -      -1.384d0,-1.378d0,-1.372d0,
     -      -1.366d0,-1.36d0,-1.354d0,
     -      -1.348d0,-1.342d0,-1.336d0,
     -      -1.331d0,-1.325d0,-1.319d0,
     -      -1.313d0,-1.308d0,-1.302d0,
     -      -1.296d0,-1.291d0,-1.285d0,
     -      -1.28d0,-1.274d0,-1.269d0,
     -      -1.264d0,-1.258d0,-1.253d0,
     -      -1.248d0,-1.242d0,-1.237d0,
     -      -1.232d0,-1.227d0,-1.222d0,
     -      -1.217d0,-1.212d0,-1.206d0,
     -      -1.201d0,-1.197d0,-1.192d0,
     -      -1.187d0,-1.182d0,-1.177d0,
     -      -1.172d0,-1.167d0,-1.163d0,
     -      -1.158d0,-1.153d0,-1.149d0,
     -      -1.144d0,-1.139d0,-1.135d0,
     -      -1.13d0,-1.126d0,-1.121d0,
     -      -1.117d0,-1.112d0,-1.108d0,
     -      -1.104d0,-1.099d0,-1.095d0,
     -      -1.091d0,-1.086d0,-1.082d0,
     -      -1.078d0,-1.074d0,-1.069d0,
     -      -1.065d0,-1.061d0,-1.057d0,
     -      -1.053d0,-1.049d0,-1.045d0,
     -      -1.041d0,-1.037d0,-1.033d0,
     -      -1.029d0,-1.025d0,-1.021d0,
     -      -1.017d0,-1.013d0,-1.01d0,
     -      -1.006d0,-1.002d0,-0.9982d0,
     -      -0.9944d0,-0.9907d0,
     -      -0.987d0,-0.9833d0,-0.9797d0,
     -      -0.976d0,-0.9724d0,
     -      -0.9688d0,-0.9652d0,-0.9617d0,
     -      -0.9581d0,-0.9546d0,
     -      -0.9511d0,-0.9476d0,-0.9442d0,
     -      -0.9407d0,-0.9373d0,
     -      -0.9339d0,-0.9305d0,-0.9271d0,
     -      -0.9238d0,-0.9205d0,
     -      -0.9171d0,-0.9139d0,-0.9106d0,
     -      -0.9073d0,-0.9041d0,
     -      -0.9008d0,-0.8976d0,-0.8945d0,
     -      -0.8913d0,-0.8881d0,
     -      -0.885d0,-0.8819d0,-0.8788d0,
     -      -0.8757d0,-0.8726d0,
     -      -0.8695d0,-0.8665d0,-0.8635d0,
     -      -0.8605d0,-0.8575d0,
     -      -0.8545d0,-0.8515d0,-0.8486d0,
     -      -0.8457d0,-0.8428d0,
     -      -0.8399d0,-0.837d0,-0.8341d0,
     -      -0.8312d0,-0.8284d0,
     -      -0.8256d0,-0.8228d0,-0.82d0,
     -      -0.8172d0,-0.8144d0,
     -      -0.8117d0,-0.8089d0,-0.8062d0,
     -      -0.8035d0,-0.8008d0,
     -      -0.7981d0,-0.7954d0,-0.7928d0,
     -      -0.7901d0,-0.7875d0,
     -      -0.7849d0,-0.7823d0,-0.7797d0,
     -      -0.7771d0,-0.7746d0,
     -      -0.772d0,-0.7695d0,-0.7669d0,
     -      -0.7644d0,-0.7619d0,
     -      -0.7594d0,-0.757d0,-0.7545d0,
     -      -0.752d0,-0.7496d0,
     -      -0.7472d0,-0.7447d0,-0.7423d0,
     -      -0.7399d0,-0.7376d0,
     -      -0.7352d0,-0.7328d0,-0.7305d0,
     -      -0.7281d0,-0.7258d0,
     -      -0.7235d0,-0.7212d0,-0.7189d0,
     -      -0.7166d0,-0.7144d0,
     -      -0.7121d0,-0.7099d0,-0.7076d0,
     -      -0.7054d0,-0.7032d0,
     -      -0.701d0,-0.6988d0,-0.6966d0,
     -      -0.6944d0,-0.6922d0,
     -      -0.6901d0,-0.6879d0,-0.6858d0,
     -      -0.6837d0,-0.6816d0,
     -      -0.6795d0,-0.6774d0,-0.6753d0,
     -      -0.6732d0,-0.6711d0,
     -      -0.6691d0,-0.667d0,-0.665d0,
     -      -0.663d0,-0.661d0,-0.659d0,
     -      -0.657d0,-0.655d0,-0.653d0,
     -      -0.651d0,-0.649d0,-0.6471d0,
     -      -0.6451d0,-0.6432d0,-0.6413d0,
     -      -0.6394d0,-0.6374d0,
     -      -0.6355d0,-0.6336d0,-0.6318d0,
     -      -0.6299d0,-0.628d0,
     -      -0.6262d0,-0.6243d0,-0.6225d0,
     -      -0.6206d0,-0.6188d0,
     -      -0.617d0,-0.6152d0,-0.6134d0,
     -      -0.6116d0,-0.6098d0,
     -      -0.608d0,-0.6062d0,-0.6045d0,
     -      -0.6027d0,-0.601d0,
     -      -0.5992d0,-0.5975d0,-0.5958d0,
     -      -0.594d0,-0.5923d0,
     -      -0.5906d0,-0.5889d0,-0.5872d0,
     -      -0.5856d0,-0.5839d0,
     -      -0.5822d0,-0.5806d0,-0.5789d0,
     -      -0.5773d0,-0.5756d0,
     -      -0.574d0,-0.5724d0,-0.5708d0,
     -      -0.5691d0,-0.5675d0,
     -      -0.5659d0,-0.5643d0,-0.5628d0,
     -      -0.5612d0,-0.5596d0,
     -      -0.5581d0,-0.5565d0,-0.5549d0,
     -      -0.5534d0,-0.5519d0,
     -      -0.5503d0,-0.5488d0,-0.5473d0,
     -      -0.5458d0,-0.5443d0,
     -      -0.5428d0,-0.5413d0,-0.5398d0,
     -      -0.5383d0,-0.5368d0,
     -      -0.5354d0,-0.5339d0,-0.5325d0,
     -      -0.531d0,-0.5296d0,
     -      -0.5281d0,-0.5267d0,-0.5253d0,
     -      -0.5238d0,-0.5224d0,
     -      -0.521d0,-0.5196d0,-0.5182d0,
     -      -0.5168d0,-0.5154d0,
     -      -0.514d0,-0.5127d0,-0.5113d0,
     -      -0.5099d0,-0.5086d0,
     -      -0.5072d0,-0.5059d0,-0.5045d0,
     -      -0.5032d0,-0.5019d0,
     -      -0.5005d0,-0.4992d0,-0.4979d0,
     -      -0.4966d0,-0.4953d0,
     -      -0.494d0,-0.4927d0,-0.4914d0,
     -      -0.4901d0,-0.4888d0,
     -      -0.4876d0,-0.4863d0,-0.485d0,
     -      -0.4838d0,-0.4825d0,
     -      -0.4813d0,-0.48d0,-0.4788d0,
     -      -0.4775d0,-0.4763d0,
     -      -0.4751d0,-0.4738d0,-0.4726d0,
     -      -0.4714d0,-0.4702d0,
     -      -0.469d0,-0.4678d0,-0.4666d0,
     -      -0.4654d0,-0.4642d0,
     -      -0.4631d0,-0.4619d0,-0.4607d0,
     -      -0.4596d0,-0.4584d0,
     -      -0.4572d0,-0.4561d0,-0.4549d0,
     -      -0.4538d0,-0.4526d0,
     -      -0.4515d0,-0.4504d0,-0.4492d0,
     -      -0.4481d0,-0.447d0,
     -      -0.4459d0,-0.4448d0,-0.4437d0,
     -      -0.4426d0,-0.4415d0,
     -      -0.4404d0,-0.4393d0,-0.4382d0,
     -      -0.4371d0,-0.436d0,
     -      -0.435d0,-0.4339d0,-0.4328d0,
     -      -0.4318d0,-0.4307d0,
     -      -0.4297d0,-0.4286d0,-0.4276d0,
     -      -0.4265d0,-0.4255d0,
     -      -0.4244d0,-0.4234d0,-0.4224d0,
     -      -0.4214d0,-0.4203d0,
     -      -0.4193d0,-0.4183d0,-0.4173d0,
     -      -0.4163d0,-0.4153d0,
     -      -0.4143d0,-0.4133d0,-0.4123d0,
     -      -0.4113d0,-0.4104d0,
     -      -0.4094d0,-0.4084d0,-0.4074d0,
     -      -0.4065d0,-0.4055d0,
     -      -0.4045d0,-0.4036d0,-0.4026d0,
     -      -0.4017d0,-0.4007d0,
     -      -0.3998d0,-0.3988d0,-0.3979d0,
     -      -0.3969d0,-0.396d0,
     -      -0.3951d0,-0.3942d0,-0.3932d0,
     -      -0.3923d0,-0.3914d0,
     -      -0.3905d0,-0.3896d0,-0.3887d0,
     -      -0.3878d0,-0.3869d0,
     -      -0.386d0,-0.3851d0,-0.3842d0,
     -      -0.3833d0,-0.3824d0,
     -      -0.3815d0,-0.3807d0,-0.3798d0,
     -      -0.3789d0,-0.378d0,
     -      -0.3772d0,-0.3763d0,-0.3755d0,
     -      -0.3746d0,-0.3737d0,
     -      -0.3729d0,-0.372d0,-0.3712d0,
     -      -0.3704d0,-0.3695d0,
     -      -0.3687d0,-0.3678d0,-0.367d0,
     -      -0.3662d0,-0.3654d0,
     -      -0.3645d0,-0.3637d0,-0.3629d0,
     -      -0.3621d0,-0.3613d0,
     -      -0.3605d0,-0.3597d0,-0.3589d0,
     -      -0.3581d0,-0.3573d0,
     -      -0.3565d0,-0.3557d0,-0.3549d0,
     -      -0.3541d0,-0.3533d0,
     -      -0.3525d0,-0.3517d0,-0.351d0,
     -      -0.3502d0,-0.3494d0,
     -      -0.3486d0,-0.3479d0,
     -      -0.34711584915854166d0,
     -      -0.3464d0,-0.3456d0,-0.3448d0,
     -      -0.3441d0,-0.3433d0,
     -      -0.3426d0,-0.3418d0,
     -      -0.3411d0,-0.3403d0,-0.3396d0,
     -      -0.3389d0,-0.3381d0,-0.3374d0,
     -      -0.3367d0,-0.3359d0,
     -      -0.3352d0,-0.3345d0,
     -      -0.3338d0,-0.3331d0,-0.3323d0,
     -      -0.3316d0,-0.3309d0,-0.3302d0,
     -      -0.3295d0,-0.3288d0,
     -      -0.3281d0,-0.3274d0,-0.3267d0,
     -      -0.326d0,-0.3253d0,
     -      -0.3246d0,-0.3239d0,-0.3232d0,
     -      -0.3226d0,-0.3219d0,
     -      -0.3212d0,-0.3205d0,-0.3198d0,
     -      -0.3192d0,-0.3185d0,
     -      -0.3178d0,-0.3172d0,-0.3165d0,
     -      -0.3158d0,-0.3152d0,
     -      -0.3145d0,-0.3139d0,-0.3132d0,
     -      -0.3126d0,-0.3119d0,
     -      -0.3113d0,-0.3106d0,-0.31d0,
     -      -0.3093d0,-0.3087d0,
     -      -0.308d0,-0.3074d0,-0.3068d0,
     -      -0.3061d0,-0.3055d0,
     -      -0.3049d0,-0.3043d0,-0.3036d0,
     -      -0.303d0,-0.3024d0,
     -      -0.3018d0,-0.3011d0,-0.3005d0,
     -      -0.2999d0,-0.2993d0,
     -      -0.2987d0,-0.2981d0,-0.2975d0,
     -      -0.2969d0,-0.2963d0,
     -      -0.2957d0,-0.2951d0,-0.2945d0,
     -      -0.2939d0,-0.2933d0,
     -      -0.2927d0,-0.2921d0,-0.2915d0,
     -      -0.2909d0,-0.2904d0,
     -      -0.2898d0,-0.2892d0,-0.2886d0,
     -      -0.288d0,-0.2875d0,
     -      -0.2869d0,-0.2863d0,-0.2857d0,
     -      -0.2852d0,-0.2846d0,
     -      -0.284d0,-0.2835d0,-0.2829d0,
     -      -0.2824d0,-0.2818d0,
     -      -0.2812d0,-0.2807d0,-0.2801d0,
     -      -0.2796d0,-0.279d0,
     -      -0.2785d0,-0.2779d0,-0.2774d0,
     -      -0.2769d0,-0.2763d0,
     -      -0.2758d0,-0.2752d0,-0.2747d0,
     -      -0.2742d0,-0.2736d0,
     -      -0.2731d0,-0.2726d0,-0.272d0,
     -      -0.2715d0,-0.271d0,
     -      -0.2705d0,-0.2699d0,-0.2694d0,
     -      -0.2689d0,-0.2684d0,
     -      -0.2679d0,-0.2673d0,-0.2668d0,
     -      -0.2663d0,-0.2658d0,
     -      -0.2653d0,-0.2648d0,-0.2643d0,
     -      -0.2638d0,-0.2633d0,
     -      -0.2628d0,-0.2623d0,-0.2618d0,
     -      -0.2613d0,-0.2608d0,
     -      -0.2603d0,-0.2598d0,
     -      -0.25928273255620626d0,
     -      -0.2588d0,-0.2583d0,-0.2578d0,
     -      -0.2573d0,-0.2568d0,
     -      -0.2564d0,-0.2559d0,
     -      -0.2554d0,-0.2549d0,-0.2544d0,
     -      -0.254d0,-0.2535d0,
     -      -0.253d0,-0.2525d0,-0.2521d0,
     -      -0.2516d0,-0.2511d0,
     -      -0.2507d0,-0.2502d0,-0.2497d0,
     -      -0.2493d0,-0.2488d0,
     -      -0.2483d0,-0.2479d0,-0.2474d0,
     -      -0.247d0,-0.2465d0,
     -      -0.246d0,-0.2456d0,-0.2451d0,
     -      -0.2447d0,-0.2442d0,
     -      -0.2438d0,-0.2433d0,-0.2429d0,
     -      -0.2424d0,-0.242d0,-0.2416d0,
     -      -0.2411d0,-0.2407d0,
     -      -0.2402d0,-0.2398d0,-0.2394d0,
     -      -0.2389d0,-0.2385d0,
     -      -0.2381d0,-0.2376d0,-0.2372d0,
     -      -0.2368d0,-0.2363d0,
     -      -0.2359d0,-0.2355d0,-0.2351d0,
     -      -0.2346d0,-0.2342d0,
     -      -0.2338d0,-0.2334d0,-0.233d0,
     -      -0.2325d0,-0.2321d0,
     -      -0.2317d0,-0.2313d0,-0.2309d0,
     -      -0.2305d0,-0.2301d0,
     -      -0.2296d0,-0.2292d0,-0.2288d0,
     -      -0.2284d0,-0.228d0,
     -      -0.2276d0,-0.2272d0,-0.2268d0,
     -      -0.2264d0,-0.226d0,
     -      -0.2256d0,-0.2252d0,-0.2248d0,
     -      -0.2244d0,-0.224d0,
     -      -0.2236d0,-0.2232d0,-0.2228d0,
     -      -0.2224d0,-0.2221d0,
     -      -0.2217d0,-0.2213d0,-0.2209d0,
     -      -0.2205d0,-0.2201d0,
     -      -0.2197d0,-0.2193d0,
     -      -0.219d0,-0.2186d0,-0.2182d0,
     -      -0.2178d0,-0.2174d0,
     -      -0.2171d0,-0.2167d0,
     -      -0.2163d0,
     -      -0.2159d0,-0.2156d0,
     -      -0.2152d0,-0.2148d0,
     -      -0.2145d0,
     -      -0.2141d0,-0.2137d0,
     -      -0.2134d0,-0.213d0,-0.2126d0,
     -      -0.2123d0,-0.2119d0,
     -      -0.2115d0,-0.2112d0,
     -      -0.2108d0,
     -      -0.2105d0,-0.2101d0,
     -      -0.2097d0,-0.2094d0,
     -      -0.209d0,
     -      -0.2087d0,-0.2083d0,
     -      -0.208d0,-0.2076d0,-0.2073d0,
     -      -0.2069d0,-0.2066d0,
     -      -0.2062d0,-0.2059d0,-0.2055d0,
     -      -0.2052d0,-0.2048d0,
     -      -0.2045d0,-0.2041d0,
     -      -0.2038d0,
     -      -0.2034d0,-0.2031d0,
     -      -0.2028d0,-0.2024d0,-0.2021d0,
     -      -0.2017d0,-0.2014d0,-0.2011d0,
     -      -0.2007d0,-0.2004d0,
     -      -0.2001d0,-0.1997d0,-0.1994d0,
     -      -0.1991d0,-0.1987d0,
     -      -0.1984d0,-0.1981d0,-0.1978d0,
     -      -0.1974d0,-0.1971d0,
     -      -0.1968d0,-0.1965d0,-0.1961d0,
     -      -0.1958d0,-0.1955d0,
     -      -0.1952d0,-0.1949d0,-0.1945d0,
     -      -0.1942d0,-0.1939d0,
     -      -0.1936d0,-0.1933d0,-0.1929d0,
     -      -0.1926d0,-0.1923d0,
     -      -0.192d0,-0.1917d0,-0.1914d0,
     -      -0.1911d0,-0.1908d0,
     -      -0.1904d0,-0.1901d0,-0.1898d0,
     -      -0.1895d0,-0.1892d0,
     -      -0.1889d0,-0.1886d0,-0.1883d0,
     -      -0.188d0,-0.1877d0,
     -      -0.1874d0,-0.1871d0,-0.1868d0,
     -      -0.1865d0,-0.1862d0,
     -      -0.1859d0,-0.1856d0,-0.1853d0,
     -      -0.185d0,-0.1847d0,
     -      -0.1844d0,-0.1841d0,-0.1838d0,
     -      -0.1835d0,-0.1832d0,
     -      -0.1829d0,-0.1827d0,-0.1824d0,
     -      -0.1821d0,-0.1818d0,
     -      -0.1815d0,-0.1812d0,-0.1809d0,
     -      -0.1806d0,-0.1804d0,
     -      -0.1801d0,-0.1798d0,-0.1795d0,
     -      -0.1792d0,-0.1789d0,
     -      -0.1787d0,-0.1784d0,-0.1781d0,
     -      -0.1778d0,-0.1775d0,
     -      -0.1773d0,-0.177d0,-0.1767d0,
     -      -0.1764d0,-0.1762d0,
     -      -0.1759d0,-0.1756d0,-0.1753d0,
     -      -0.1751d0,-0.1748d0,
     -      -0.1745d0,-0.1742d0,-0.174d0,
     -      -0.1737d0,-0.1734d0,
     -      -0.1732d0,-0.1729d0,-0.1726d0,
     -      -0.1724d0,-0.1721d0,
     -      -0.1718d0,-0.1716d0,-0.1713d0,
     -      -0.171d0,-0.1708d0,
     -      -0.1705d0,-0.1703d0,-0.17d0,
     -      -0.1697d0,-0.1695d0,
     -      -0.1692d0,-0.169d0,-0.1687d0,-0.1684d0,
     -      -0.1682d0,
     -      -0.1679d0,-0.1677d0,
     -      -0.1674d0,-0.1672d0,-0.1669d0,
     -      -0.1667d0,-0.1664d0,
     -      -0.1662d0,-0.1659d0,-0.1657d0,
     -      -0.1654d0,-0.1652d0,
     -      -0.1649d0,-0.1647d0,-0.1644d0,
     -      -0.1642d0,-0.1639d0,
     -      -0.1637d0,-0.1634d0,-0.1632d0,
     -      -0.1629d0,-0.1627d0,
     -      -0.1624d0,-0.1622d0,-0.162d0,
     -      -0.1617d0,-0.1615d0,
     -      -0.1612d0,-0.161d0,-0.1608d0,
     -      -0.1605d0,-0.1603d0,
     -      -0.16d0,-0.1598d0,-0.1596d0,
     -      -0.1593d0,-0.1591d0,
     -      -0.1589d0,-0.1586d0,-0.1584d0,
     -      -0.1581d0,-0.1579d0,
     -      -0.1577d0,-0.1575d0,-0.1572d0,
     -      -0.157d0,-0.1568d0,
     -      -0.1565d0,-0.1563d0,-0.1561d0,
     -      -0.1558d0,-0.1556d0,
     -      -0.1554d0,-0.1552d0,-0.1549d0,
     -      -0.1547d0,-0.1545d0,
     -      -0.1542d0,-0.154d0,-0.1538d0,
     -      -0.1536d0,-0.1534d0,
     -      -0.1531d0,-0.1529d0,-0.1527d0,
     -      -0.1525d0,-0.1522d0,
     -      -0.152d0,-0.1518d0,-0.1516d0,
     -      -0.1514d0,-0.1511d0,
     -      -0.1509d0,-0.1507d0,-0.1505d0,
     -      -0.1503d0,-0.1501d0,
     -      -0.1498d0,-0.1496d0,-0.1494d0,
     -      -0.1492d0,-0.149d0,
     -      -0.1488d0,-0.1486d0,-0.1483d0,
     -      -0.1481d0,-0.1479d0,
     -      -0.1477d0,-0.1475d0,-0.1473d0,
     -      -0.1471d0,-0.1469d0,
     -      -0.1467d0,-0.1465d0,-0.1462d0,
     -      -0.146d0,-0.1458d0,
     -      -0.1456d0,-0.1454d0,-0.1452d0,
     -      -0.145d0,-0.1448d0,
     -      -0.1446d0,-0.1444d0,-0.1442d0,
     -      -0.144d0,-0.1438d0,
     -      -0.1436d0,-0.1434d0,-0.1432d0,
     -      -0.143d0,-0.1428d0,
     -      -0.1426d0,-0.1424d0,-0.1422d0,
     -      -0.142d0,-0.1418d0,
     -      -0.1416d0,-0.1414d0,-0.1412d0,
     -      -0.141d0,-0.1408d0,
     -      -0.1406d0,-0.1404d0,-0.1402d0,
     -      -0.14d0,-0.1398d0,
     -      -0.1396d0,-0.1394d0,-0.1392d0,
     -      -0.139d0,-0.1388d0,
     -      -0.1387d0,-0.1385d0,-0.1383d0,
     -      -0.1381d0,-0.1379d0,
     -      -0.1377d0,-0.1375d0,-0.1373d0,
     -      -0.1371d0,-0.1369d0,
     -      -0.1368d0,-0.1366d0,-0.1364d0,
     -      -0.1362d0,-0.136d0,
     -      -0.1358d0,-0.1356d0,-0.1355d0,
     -      -0.1353d0,-0.1351d0,
     -      -0.1349d0,-0.1347d0,-0.1345d0,
     -      -0.1343d0,-0.1342d0,
     -      -0.134d0,-0.1338d0,-0.1336d0,
     -      -0.1334d0,-0.1333d0,
     -      -0.1331d0,-0.1329d0,-0.1327d0,
     -      -0.1325d0,-0.1324d0,
     -      -0.1322d0,-0.132d0,-0.1318d0,
     -      -0.1316d0,-0.1315d0,
     -      -0.1313d0,-0.1311d0,-0.1309d0,
     -      -0.1308d0,-0.1306d0,
     -      -0.1304d0,-0.1302d0,-0.1301d0,
     -      -0.1299d0,-0.1297d0,
     -      -0.1295d0,-0.1294d0,-0.1292d0,
     -      -0.129d0,-0.1289d0,
     -      -0.1287d0,-0.1285d0,-0.1283d0,
     -      -0.1282d0,-0.128d0,
     -      -0.1278d0,-0.1277d0,-0.1275d0,
     -      -0.12731996531685635d0,
     -      -0.1272d0,-0.127d0,
     -      -0.1268d0,-0.1266d0,
     -      -0.1265d0,-0.1263d0,-0.1261d0,
     -      -0.126d0,-0.1258d0,
     -      -0.1256d0,-0.1255d0,-0.1253d0,
     -      -0.1252d0/

      if ((mhiggs.le.20).or.(mhiggs.ge.1500)) then
         ReA1 = 0.d0
         ImA1 = 0.d0
         return
      end if

      i2 = -100000
      do i1 = 0,1480
         if (((i1+20).Le.mhiggs).And.((i1+21).Ge.mhiggs)) i2 = i1
      end do
      if (i2.eq.-100000) then
         write(*,*) 'SusHi error in CalcA1MZ'
         stop
      endif

      ReA1 = (realvalues(i2+2) - realvalues(i2+1))
     &     * (mhiggs - i2 - 20.D0) + realvalues(i2+1)

      ImA1 = (imvalues(i2+2) - imvalues(i2+1))
     &     * (mhiggs - i2 - 20.D0) + imvalues(i2+1)


      end

C-}}}
